from typing import Optional, List

from vkbottle_types.objects import (
    NotificationsNotificationItem,
    VideoVideo,
    UsersUser,
    PhotosPhoto,
    GroupsGroup,
    AppsApp,
    BaseBoolInt,
    NotificationsSendMessageItem,
)
from .base_response import BaseResponse


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class MarkAsViewedResponse(BaseResponse):
    response: Optional["MarkAsViewedResponseModel"] = None


class SendMessageResponse(BaseResponse):
    response: Optional["SendMessageResponseModel"] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["NotificationsNotificationItem"]] = None
    profiles: Optional[List["UsersUser"]] = None
    groups: Optional[List["GroupsGroup"]] = None
    last_viewed: Optional[int] = None
    photos: Optional[List["PhotosPhoto"]] = None
    videos: Optional[List["VideoVideo"]] = None
    apps: Optional[List["AppsApp"]] = None
    next_from: Optional[str] = None
    ttl: Optional[int] = None


MarkAsViewedResponseModel = Optional[BaseBoolInt]

SendMessageResponseModel = List[NotificationsSendMessageItem]

GetResponse.update_forward_refs()
MarkAsViewedResponse.update_forward_refs()
SendMessageResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    BoardTopicComment,
    UsersUserMin,
    UsersUser,
    GroupsGroup,
    BaseBoolInt,
    BoardTopicPoll,
    BoardDefaultOrder,
    BoardTopic,
)
from .base_response import BaseResponse


class AddTopicResponse(BaseResponse):
    response: Optional["AddTopicResponseModel"] = None


class CreateCommentResponse(BaseResponse):
    response: Optional["CreateCommentResponseModel"] = None


class GetCommentsExtendedResponse(BaseResponse):
    response: Optional["GetCommentsExtendedResponseModel"] = None


class GetCommentsResponse(BaseResponse):
    response: Optional["GetCommentsResponseModel"] = None


class GetTopicsExtendedResponse(BaseResponse):
    response: Optional["GetTopicsExtendedResponseModel"] = None


class GetTopicsResponse(BaseResponse):
    response: Optional["GetTopicsResponseModel"] = None


AddTopicResponseModel = int

CreateCommentResponseModel = int


class GetCommentsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["BoardTopicComment"]] = None
    poll: Optional["BoardTopicPoll"] = None
    profiles: Optional[List["UsersUser"]] = None
    groups: Optional[List["GroupsGroup"]] = None


class GetCommentsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["BoardTopicComment"]] = None
    poll: Optional["BoardTopicPoll"] = None


class GetTopicsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["BoardTopic"]] = None
    default_order: Optional["BoardDefaultOrder"] = None
    can_add_topics: Optional["BaseBoolInt"] = None
    profiles: Optional[List["UsersUserMin"]] = None


class GetTopicsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["BoardTopic"]] = None
    default_order: Optional["BoardDefaultOrder"] = None
    can_add_topics: Optional["BaseBoolInt"] = None


AddTopicResponse.update_forward_refs()
CreateCommentResponse.update_forward_refs()
GetCommentsExtendedResponse.update_forward_refs()
GetCommentsResponse.update_forward_refs()
GetTopicsExtendedResponse.update_forward_refs()
GetTopicsResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.responses import notifications
from .base_category import BaseCategory


class NotificationsCategory(BaseCategory):
    async def get(
        self,
        count: Optional[int] = None,
        start_from: Optional[str] = None,
        filters: Optional[List[str]] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        **kwargs
    ) -> notifications.GetResponseModel:
        """Returns a list of notifications about other users' feedback to the current user's wall posts.
        :param count: Number of notifications to return.
        :param start_from:
        :param filters: Type of notifications to return: 'wall' — wall posts, 'mentions' — mentions in wall posts, comments, or topics, 'comments' — comments to wall posts, photos, and videos, 'likes' — likes, 'reposted' — wall posts that are copied from the current user's wall, 'followers' — new followers, 'friends' — accepted friend requests
        :param start_time: Earliest timestamp (in Unix time, **kwargs) of a notification to return. By default, 24 hours ago.
        :param end_time: Latest timestamp (in Unix time, **kwargs) of a notification to return. By default, the current time.
        """

        params = self.get_set_params(locals())
        return notifications.GetResponse(
            **await self.api.request("notifications.get", params)
        )

    async def mark_as_viewed(self, **kwargs) -> notifications.MarkAsViewedResponseModel:
        """Resets the counter of new notifications about other users' feedback to the current user's wall posts."""

        params = self.get_set_params(locals())
        return notifications.MarkAsViewedResponse(
            **await self.api.request("notifications.markAsViewed", params)
        )

    async def send_message(
        self,
        user_ids: List[int],
        message: str,
        fragment: Optional[str] = None,
        group_id: Optional[int] = None,
        random_id: Optional[int] = None,
        **kwargs
    ) -> notifications.SendMessageResponseModel:
        """notifications.sendMessage method
        :param user_ids:
        :param message:
        :param fragment:
        :param group_id:
        :param random_id:
        """

        params = self.get_set_params(locals())
        return notifications.SendMessageResponse(
            **await self.api.request("notifications.sendMessage", params)
        )



from typing import Optional, List

from vkbottle_types.objects import (
    LeadsChecked,
    LeadsComplete,
    LeadsStart,
    LeadsLead,
    LeadsEntry,
)
from .base_response import BaseResponse


class CheckUserResponse(BaseResponse):
    response: Optional["CheckUserResponseModel"] = None


class CompleteResponse(BaseResponse):
    response: Optional["CompleteResponseModel"] = None


class GetStatsResponse(BaseResponse):
    response: Optional["GetStatsResponseModel"] = None


class GetUsersResponse(BaseResponse):
    response: Optional["GetUsersResponseModel"] = None


class MetricHitResponse(BaseResponse):
    response: Optional["MetricHitResponseModel"] = None


class StartResponse(BaseResponse):
    response: Optional["StartResponseModel"] = None


CheckUserResponseModel = Optional[LeadsChecked]

CompleteResponseModel = Optional[LeadsComplete]

GetStatsResponseModel = Optional[LeadsLead]

GetUsersResponseModel = List[LeadsEntry]


class MetricHitResponseModel(BaseResponse):
    result: Optional[bool] = None
    redirect_link: Optional[str] = None


StartResponseModel = Optional[LeadsStart]

CheckUserResponse.update_forward_refs()
CompleteResponse.update_forward_refs()
GetStatsResponse.update_forward_refs()
GetUsersResponse.update_forward_refs()
MetricHitResponse.update_forward_refs()
StartResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    UtilsLinkStatsExtended,
    UtilsLinkChecked,
    UtilsShortLink,
    UtilsLinkStats,
    UtilsLastShortenedLink,
    UtilsDomainResolved,
)
from .base_response import BaseResponse


class CheckLinkResponse(BaseResponse):
    response: Optional["CheckLinkResponseModel"] = None


class GetLastShortenedLinksResponse(BaseResponse):
    response: Optional["GetLastShortenedLinksResponseModel"] = None


class GetLinkStatsExtendedResponse(BaseResponse):
    response: Optional["GetLinkStatsExtendedResponseModel"] = None


class GetLinkStatsResponse(BaseResponse):
    response: Optional["GetLinkStatsResponseModel"] = None


class GetServerTimeResponse(BaseResponse):
    response: Optional["GetServerTimeResponseModel"] = None


class GetShortLinkResponse(BaseResponse):
    response: Optional["GetShortLinkResponseModel"] = None


class ResolveScreenNameResponse(BaseResponse):
    response: Optional["ResolveScreenNameResponseModel"] = None


CheckLinkResponseModel = Optional[UtilsLinkChecked]


class GetLastShortenedLinksResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["UtilsLastShortenedLink"]] = None


GetLinkStatsExtendedResponseModel = Optional[UtilsLinkStatsExtended]

GetLinkStatsResponseModel = Optional[UtilsLinkStats]


GetServerTimeResponseModel = int

GetShortLinkResponseModel = Optional[UtilsShortLink]

ResolveScreenNameResponseModel = Optional[UtilsDomainResolved]

CheckLinkResponse.update_forward_refs()
GetLastShortenedLinksResponse.update_forward_refs()
GetLinkStatsExtendedResponse.update_forward_refs()
GetLinkStatsResponse.update_forward_refs()
GetServerTimeResponse.update_forward_refs()
GetShortLinkResponse.update_forward_refs()
ResolveScreenNameResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.responses import leads
from .base_category import BaseCategory


class LeadsCategory(BaseCategory):
    async def check_user(
        self,
        lead_id: int,
        test_result: Optional[int] = None,
        test_mode: Optional[bool] = None,
        auto_start: Optional[bool] = None,
        age: Optional[int] = None,
        country: Optional[str] = None,
        **kwargs
    ) -> leads.CheckUserResponseModel:
        """Checks if the user can start the lead.
        :param lead_id: Lead ID.
        :param test_result: Value to be return in 'result' field when test mode is used.
        :param test_mode:
        :param auto_start:
        :param age: User age.
        :param country: User country code.
        """

        params = self.get_set_params(locals())
        return leads.CheckUserResponse(
            **await self.api.request("leads.checkUser", params)
        )

    async def complete(
        self, vk_sid: str, secret: str, comment: Optional[str] = None, **kwargs
    ) -> leads.CompleteResponseModel:
        """Completes the lead started by user.
        :param vk_sid: Session obtained as GET parameter when session started.
        :param secret: Secret key from the lead testing interface.
        :param comment: Comment text.
        """

        params = self.get_set_params(locals())
        return leads.CompleteResponse(
            **await self.api.request("leads.complete", params)
        )

    async def get_stats(
        self,
        lead_id: int,
        secret: Optional[str] = None,
        date_start: Optional[str] = None,
        date_end: Optional[str] = None,
        **kwargs
    ) -> leads.GetStatsResponseModel:
        """Returns lead stats data.
        :param lead_id: Lead ID.
        :param secret: Secret key obtained from the lead testing interface.
        :param date_start: Day to start stats from (YYYY_MM_DD, e.g.2011-09-17).
        :param date_end: Day to finish stats (YYYY_MM_DD, e.g.2011-09-17).
        """

        params = self.get_set_params(locals())
        return leads.GetStatsResponse(
            **await self.api.request("leads.getStats", params)
        )

    async def get_users(
        self,
        offer_id: int,
        secret: str,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        status: Optional[int] = None,
        reverse: Optional[bool] = None,
        **kwargs
    ) -> leads.GetUsersResponseModel:
        """Returns a list of last user actions for the offer.
        :param offer_id: Offer ID.
        :param secret: Secret key obtained in the lead testing interface.
        :param offset: Offset needed to return a specific subset of results.
        :param count: Number of results to return.
        :param status: Action type. Possible values: *'0' — start,, *'1' — finish,, *'2' — blocking users,, *'3' — start in a test mode,, *'4' — finish in a test mode.
        :param reverse: Sort order. Possible values: *'1' — chronological,, *'0' — reverse chronological.
        """

        params = self.get_set_params(locals())
        return leads.GetUsersResponse(
            **await self.api.request("leads.getUsers", params)
        )

    async def metric_hit(self, data: str, **kwargs) -> leads.MetricHitResponseModel:
        """Counts the metric event.
        :param data: Metric data obtained in the lead interface.
        """

        params = self.get_set_params(locals())
        return leads.MetricHitResponse(
            **await self.api.request("leads.metricHit", params)
        )

    async def start(
        self,
        lead_id: int,
        secret: str,
        uid: Optional[int] = None,
        aid: Optional[int] = None,
        test_mode: Optional[bool] = None,
        force: Optional[bool] = None,
        **kwargs
    ) -> leads.StartResponseModel:
        """Creates new session for the user passing the offer.
        :param lead_id: Lead ID.
        :param secret: Secret key from the lead testing interface.
        :param uid:
        :param aid:
        :param test_mode:
        :param force:
        """

        params = self.get_set_params(locals())
        return leads.StartResponse(**await self.api.request("leads.start", params))



from typing import Optional, List

from vkbottle_types.responses import account, base
from .base_category import BaseCategory


class AccountCategory(BaseCategory):
    async def ban(
        self, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """account.ban method
        :param owner_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("account.ban", params))

    async def change_password(
        self,
        new_password: str,
        restore_sid: Optional[str] = None,
        change_password_hash: Optional[str] = None,
        old_password: Optional[str] = None,
        **kwargs
    ) -> account.ChangePasswordResponseModel:
        """Changes a user password after access is successfully restored with the [vk.com/dev/auth.restore|auth.restore] method.
        :param new_password: New password that will be set as a current
        :param restore_sid: Session id received after the [vk.com/dev/auth.restore|auth.restore] method is executed. (If the password is changed right after the access was restored)
        :param change_password_hash: Hash received after a successful OAuth authorization with a code got by SMS. (If the password is changed right after the access was restored)
        :param old_password: Current user password.
        """

        params = self.get_set_params(locals())
        return account.ChangePasswordResponse(
            **await self.api.request("account.changePassword", params)
        )

    async def get_active_offers(
        self, offset: Optional[int] = None, count: Optional[int] = None, **kwargs
    ) -> account.GetActiveOffersResponseModel:
        """Returns a list of active ads (offers, **kwargs) which executed by the user will bring him/her respective number of votes to his balance in the application.
        :param offset:
        :param count: Number of results to return.
        """

        params = self.get_set_params(locals())
        return account.GetActiveOffersResponse(
            **await self.api.request("account.getActiveOffers", params)
        )

    async def get_app_permissions(
        self, user_id: int, **kwargs
    ) -> account.GetAppPermissionsResponseModel:
        """Gets settings of the user in this application.
        :param user_id: User ID whose settings information shall be got. By default: current user.
        """

        params = self.get_set_params(locals())
        return account.GetAppPermissionsResponse(
            **await self.api.request("account.getAppPermissions", params)
        )

    async def get_banned(
        self, offset: Optional[int] = None, count: Optional[int] = None, **kwargs
    ) -> account.GetBannedResponseModel:
        """Returns a user's blacklist.
        :param offset: Offset needed to return a specific subset of results.
        :param count: Number of results to return.
        """

        params = self.get_set_params(locals())
        return account.GetBannedResponse(
            **await self.api.request("account.getBanned", params)
        )

    async def get_counters(
        self, filter: Optional[List[str]] = None, **kwargs
    ) -> account.GetCountersResponseModel:
        """Returns non-null values of user counters.
        :param filter: Counters to be returned.
        """

        params = self.get_set_params(locals())
        return account.GetCountersResponse(
            **await self.api.request("account.getCounters", params)
        )

    async def get_info(
        self, fields: Optional[List[str]] = None, **kwargs
    ) -> account.GetInfoResponseModel:
        """Returns current account info.
        :param fields: Fields to return. Possible values: *'country' — user country,, *'https_required' — is "HTTPS only" option enabled,, *'own_posts_default' — is "Show my posts only" option is enabled,, *'no_wall_replies' — are wall replies disabled or not,, *'intro' — is intro passed by user or not,, *'lang' — user language. By default: all.
        """

        params = self.get_set_params(locals())
        return account.GetInfoResponse(
            **await self.api.request("account.getInfo", params)
        )

    async def get_profile_info(self, **kwargs) -> account.GetProfileInfoResponseModel:
        """Returns the current account info."""

        params = self.get_set_params(locals())
        return account.GetProfileInfoResponse(
            **await self.api.request("account.getProfileInfo", params)
        )

    async def get_push_settings(
        self, device_id: Optional[str] = None, **kwargs
    ) -> account.GetPushSettingsResponseModel:
        """Gets settings of push notifications.
        :param device_id: Unique device ID.
        """

        params = self.get_set_params(locals())
        return account.GetPushSettingsResponse(
            **await self.api.request("account.getPushSettings", params)
        )

    async def register_device(
        self,
        token: str,
        device_id: str,
        device_model: Optional[str] = None,
        device_year: Optional[int] = None,
        system_version: Optional[str] = None,
        settings: Optional[str] = None,
        sandbox: Optional[bool] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Subscribes an iOS/Android/Windows Phone-based device to receive push notifications
        :param token: Device token used to send notifications. (for mpns, the token shall be URL for sending of notifications)
        :param device_id: Unique device ID.
        :param device_model: String name of device model.
        :param device_year: Device year.
        :param system_version: String version of device operating system.
        :param settings: Push settings in a [vk.com/dev/push_settings|special format].
        :param sandbox:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("account.registerDevice", params)
        )

    async def save_profile_info(
        self,
        first_name: Optional[str] = None,
        last_name: Optional[str] = None,
        maiden_name: Optional[str] = None,
        screen_name: Optional[str] = None,
        cancel_request_id: Optional[int] = None,
        sex: Optional[int] = None,
        relation: Optional[int] = None,
        relation_partner_id: Optional[int] = None,
        bdate: Optional[str] = None,
        bdate_visibility: Optional[int] = None,
        home_town: Optional[str] = None,
        country_id: Optional[int] = None,
        city_id: Optional[int] = None,
        status: Optional[str] = None,
        **kwargs
    ) -> account.SaveProfileInfoResponseModel:
        """Edits current profile info.
        :param first_name: User first name.
        :param last_name: User last name.
        :param maiden_name: User maiden name (female only)
        :param screen_name: User screen name.
        :param cancel_request_id: ID of the name change request to be canceled. If this parameter is sent, all the others are ignored.
        :param sex: User sex. Possible values: , * '1' – female,, * '2' – male.
        :param relation: User relationship status. Possible values: , * '1' – single,, * '2' – in a relationship,, * '3' – engaged,, * '4' – married,, * '5' – it's complicated,, * '6' – actively searching,, * '7' – in love,, * '0' – not specified.
        :param relation_partner_id: ID of the relationship partner.
        :param bdate: User birth date, format: DD.MM.YYYY.
        :param bdate_visibility: Birth date visibility. Returned values: , * '1' – show birth date,, * '2' – show only month and day,, * '0' – hide birth date.
        :param home_town: User home town.
        :param country_id: User country.
        :param city_id: User city.
        :param status: Status text.
        """

        params = self.get_set_params(locals())
        return account.SaveProfileInfoResponse(
            **await self.api.request("account.saveProfileInfo", params)
        )

    async def set_info(
        self, name: Optional[str] = None, value: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """Allows to edit the current account info.
        :param name: Setting name.
        :param value: Setting value.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("account.setInfo", params))

    async def set_name_in_menu(
        self, user_id: int, name: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """Sets an application screen name (up to 17 characters), that is shown to the user in the left menu.
        :param user_id: User ID.
        :param name: Application screen name.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("account.setNameInMenu", params)
        )

    async def set_offline(self, **kwargs) -> base.OkResponseModel:
        """Marks a current user as offline."""

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("account.setOffline", params))

    async def set_online(
        self, voip: Optional[bool] = None, **kwargs
    ) -> base.OkResponseModel:
        """Marks the current user as online for 15 minutes.
        :param voip: '1' if videocalls are available for current device.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("account.setOnline", params))

    async def set_push_settings(
        self,
        device_id: str,
        settings: Optional[str] = None,
        key: Optional[str] = None,
        value: Optional[List[str]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Change push settings.
        :param device_id: Unique device ID.
        :param settings: Push settings in a [vk.com/dev/push_settings|special format].
        :param key: Notification key.
        :param value: New value for the key in a [vk.com/dev/push_settings|special format].
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("account.setPushSettings", params)
        )

    async def set_silence_mode(
        self,
        device_id: Optional[str] = None,
        time: Optional[int] = None,
        peer_id: Optional[int] = None,
        sound: Optional[int] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Mutes push notifications for the set period of time.
        :param device_id: Unique device ID.
        :param time: Time in seconds for what notifications should be disabled. '-1' to disable forever.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        :param sound: '1' — to enable sound in this dialog, '0' — to disable sound. Only if 'peer_id' contains user or community ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("account.setSilenceMode", params)
        )

    async def unban(
        self, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """account.unban method
        :param owner_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("account.unban", params))

    async def unregister_device(
        self, device_id: Optional[str] = None, sandbox: Optional[bool] = None, **kwargs
    ) -> base.OkResponseModel:
        """Unsubscribes a device from push notifications.
        :param device_id: Unique device ID.
        :param sandbox:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("account.unregisterDevice", params)
        )



from typing import Optional, List

from vkbottle_types.responses import notes, base
from .base_category import BaseCategory


class NotesCategory(BaseCategory):
    async def add(
        self,
        title: str,
        text: str,
        privacy_view: Optional[List[str]] = None,
        privacy_comment: Optional[List[str]] = None,
        **kwargs
    ) -> notes.AddResponseModel:
        """Creates a new note for the current user.
        :param title: Note title.
        :param text: Note text.
        :param privacy_view:
        :param privacy_comment:
        """

        params = self.get_set_params(locals())
        return notes.AddResponse(**await self.api.request("notes.add", params))

    async def create_comment(
        self,
        note_id: int,
        message: str,
        owner_id: Optional[int] = None,
        reply_to: Optional[int] = None,
        guid: Optional[str] = None,
        **kwargs
    ) -> notes.CreateCommentResponseModel:
        """Adds a new comment on a note.
        :param note_id: Note ID.
        :param message: Comment text.
        :param owner_id: Note owner ID.
        :param reply_to: ID of the user to whom the reply is addressed (if the comment is a reply to another comment).
        :param guid:
        """

        params = self.get_set_params(locals())
        return notes.CreateCommentResponse(
            **await self.api.request("notes.createComment", params)
        )

    async def delete(self, note_id: int, **kwargs) -> base.OkResponseModel:
        """Deletes a note of the current user.
        :param note_id: Note ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("notes.delete", params))

    async def delete_comment(
        self, comment_id: int, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Deletes a comment on a note.
        :param comment_id: Comment ID.
        :param owner_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("notes.deleteComment", params))

    async def edit(
        self,
        note_id: int,
        title: str,
        text: str,
        privacy_view: Optional[List[str]] = None,
        privacy_comment: Optional[List[str]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Edits a note of the current user.
        :param note_id: Note ID.
        :param title: Note title.
        :param text: Note text.
        :param privacy_view:
        :param privacy_comment:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("notes.edit", params))

    async def edit_comment(
        self, comment_id: int, message: str, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Edits a comment on a note.
        :param comment_id: Comment ID.
        :param message: New comment text.
        :param owner_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("notes.editComment", params))

    async def get(
        self,
        note_ids: Optional[List[int]] = None,
        user_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        sort: Optional[int] = None,
        **kwargs
    ) -> notes.GetResponseModel:
        """Returns a list of notes created by a user.
        :param note_ids: Note IDs.
        :param user_id: Note owner ID.
        :param offset:
        :param count: Number of notes to return.
        :param sort:
        """

        params = self.get_set_params(locals())
        return notes.GetResponse(**await self.api.request("notes.get", params))

    async def get_by_id(
        self,
        note_id: int,
        owner_id: Optional[int] = None,
        need_wiki: Optional[bool] = None,
        **kwargs
    ) -> notes.GetByIdResponseModel:
        """Returns a note by its ID.
        :param note_id: Note ID.
        :param owner_id: Note owner ID.
        :param need_wiki:
        """

        params = self.get_set_params(locals())
        return notes.GetByIdResponse(**await self.api.request("notes.getById", params))

    async def get_comments(
        self,
        note_id: int,
        owner_id: Optional[int] = None,
        sort: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> notes.GetCommentsResponseModel:
        """Returns a list of comments on a note.
        :param note_id: Note ID.
        :param owner_id: Note owner ID.
        :param sort:
        :param offset:
        :param count: Number of comments to return.
        """

        params = self.get_set_params(locals())
        return notes.GetCommentsResponse(
            **await self.api.request("notes.getComments", params)
        )

    async def restore_comment(
        self, comment_id: int, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Restores a deleted comment on a note.
        :param comment_id: Comment ID.
        :param owner_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("notes.restoreComment", params))



from typing import Optional

from pydantic import BaseModel


class BaseResponse(BaseModel):
    _raw_json: Optional[str] = None

    @property
    def raw_json(self) -> str:
        if not self.raw_json:
            raise AttributeError(
                "You cannot get raw_json from here. Get a full raw_json from unnested response"
            )
        return self._raw_json



from typing import Optional, List

from vkbottle_types.objects import GiftsGift
from .base_response import BaseResponse


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["GiftsGift"]] = None


GetResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.objects import BaseUploadServer, BaseBoolInt
from .base_response import BaseResponse


class BoolResponse(BaseResponse):
    response: Optional["BoolResponseModel"] = None


class GetUploadServerResponse(BaseResponse):
    response: Optional["GetUploadServerResponseModel"] = None


class OkResponse(BaseResponse):
    response: Optional["OkResponseModel"] = None


BoolResponseModel = Optional[BaseBoolInt]

GetUploadServerResponseModel = Optional[BaseUploadServer]

OkResponseModel = int

BoolResponse.update_forward_refs()
GetUploadServerResponse.update_forward_refs()
OkResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.responses import stats, base
from .base_category import BaseCategory


class StatsCategory(BaseCategory):
    async def get(
        self,
        group_id: Optional[int] = None,
        app_id: Optional[int] = None,
        timestamp_from: Optional[int] = None,
        timestamp_to: Optional[int] = None,
        interval: Optional[str] = None,
        intervals_count: Optional[int] = None,
        filters: Optional[List[str]] = None,
        stats_groups: Optional[List[str]] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> stats.GetResponseModel:
        """Returns statistics of a community or an application.
        :param group_id: Community ID.
        :param app_id: Application ID.
        :param timestamp_from:
        :param timestamp_to:
        :param interval:
        :param intervals_count:
        :param filters:
        :param stats_groups:
        :param extended:
        """

        params = self.get_set_params(locals())
        return stats.GetResponse(**await self.api.request("stats.get", params))

    async def get_post_reach(
        self, owner_id: str, post_ids: List[int], **kwargs
    ) -> stats.GetPostReachResponseModel:
        """Returns stats for a wall post.
        :param owner_id: post owner community id. Specify with "-" sign.
        :param post_ids: wall posts id
        """

        params = self.get_set_params(locals())
        return stats.GetPostReachResponse(
            **await self.api.request("stats.getPostReach", params)
        )

    async def track_visitor(self, id: str, **kwargs) -> base.OkResponseModel:
        """stats.trackVisitor method
        :param id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("stats.trackVisitor", params))



import typing
from typing import Optional, List

from vkbottle_types.responses import fave, base
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import base as objects_base


class FaveCategory(BaseCategory):
    async def add_article(self, url: str, **kwargs) -> base.OkResponseModel:
        """fave.addArticle method
        :param url:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.addArticle", params))

    async def add_link(self, link: str, **kwargs) -> base.OkResponseModel:
        """Adds a link to user faves.
        :param link: Link URL.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.addLink", params))

    async def add_page(
        self, user_id: Optional[int] = None, group_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """fave.addPage method
        :param user_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.addPage", params))

    async def add_post(
        self, owner_id: int, id: int, access_key: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """fave.addPost method
        :param owner_id:
        :param id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.addPost", params))

    async def add_product(
        self, owner_id: int, id: int, access_key: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """fave.addProduct method
        :param owner_id:
        :param id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.addProduct", params))

    async def add_tag(
        self, name: Optional[str] = None, position: Optional[str] = None, **kwargs
    ) -> fave.AddTagResponseModel:
        """fave.addTag method
        :param name:
        :param position:
        """

        params = self.get_set_params(locals())
        return fave.AddTagResponse(**await self.api.request("fave.addTag", params))

    async def add_video(
        self, owner_id: int, id: int, access_key: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """fave.addVideo method
        :param owner_id:
        :param id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.addVideo", params))

    async def edit_tag(self, id: int, name: str, **kwargs) -> base.OkResponseModel:
        """fave.editTag method
        :param id:
        :param name:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.editTag", params))

    async def get(
        self,
        extended: Optional[bool] = None,
        item_type: Optional[str] = None,
        tag_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[str] = None,
        is_from_snackbar: Optional[bool] = None,
        **kwargs
    ) -> fave.GetExtendedResponseModel:
        """fave.get method
        :param extended: '1' — to return additional 'wall', 'profiles', and 'groups' fields. By default: '0'.
        :param item_type:
        :param tag_id: Tag ID.
        :param offset: Offset needed to return a specific subset of users.
        :param count: Number of users to return.
        :param fields:
        :param is_from_snackbar:
        """

        params = self.get_set_params(locals())
        return fave.GetExtendedResponse(**await self.api.request("fave.get", params))

    async def get_pages(
        self,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        type: Optional[str] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        tag_id: Optional[int] = None,
        **kwargs
    ) -> fave.GetPagesResponseModel:
        """fave.getPages method
        :param offset:
        :param count:
        :param type:
        :param fields:
        :param tag_id:
        """

        params = self.get_set_params(locals())
        return fave.GetPagesResponse(**await self.api.request("fave.getPages", params))

    async def get_tags(self, **kwargs) -> fave.GetTagsResponseModel:
        """fave.getTags method"""

        params = self.get_set_params(locals())
        return fave.GetTagsResponse(**await self.api.request("fave.getTags", params))

    async def mark_seen(self, **kwargs) -> base.BoolResponseModel:
        """fave.markSeen method"""

        params = self.get_set_params(locals())
        return base.BoolResponse(**await self.api.request("fave.markSeen", params))

    async def remove_article(
        self, owner_id: int, article_id: int, **kwargs
    ) -> base.BoolResponseModel:
        """fave.removeArticle method
        :param owner_id:
        :param article_id:
        """

        params = self.get_set_params(locals())
        return base.BoolResponse(**await self.api.request("fave.removeArticle", params))

    async def remove_link(
        self, link_id: Optional[str] = None, link: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """Removes link from the user's faves.
        :param link_id: Link ID (can be obtained by [vk.com/dev/faves.getLinks|faves.getLinks] method).
        :param link: Link URL
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.removeLink", params))

    async def remove_page(
        self, user_id: Optional[int] = None, group_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """fave.removePage method
        :param user_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.removePage", params))

    async def remove_post(
        self, owner_id: int, id: int, **kwargs
    ) -> base.OkResponseModel:
        """fave.removePost method
        :param owner_id:
        :param id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.removePost", params))

    async def remove_product(
        self, owner_id: int, id: int, **kwargs
    ) -> base.OkResponseModel:
        """fave.removeProduct method
        :param owner_id:
        :param id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.removeProduct", params))

    async def remove_tag(self, id: int, **kwargs) -> base.OkResponseModel:
        """fave.removeTag method
        :param id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.removeTag", params))

    async def reorder_tags(self, ids: List[int], **kwargs) -> base.OkResponseModel:
        """fave.reorderTags method
        :param ids:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.reorderTags", params))

    async def set_page_tags(
        self,
        user_id: Optional[int] = None,
        group_id: Optional[int] = None,
        tag_ids: Optional[List[int]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """fave.setPageTags method
        :param user_id:
        :param group_id:
        :param tag_ids:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.setPageTags", params))

    async def set_tags(
        self,
        item_type: Optional[str] = None,
        item_owner_id: Optional[int] = None,
        item_id: Optional[int] = None,
        tag_ids: Optional[List[int]] = None,
        link_id: Optional[str] = None,
        link_url: Optional[str] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """fave.setTags method
        :param item_type:
        :param item_owner_id:
        :param item_id:
        :param tag_ids:
        :param link_id:
        :param link_url:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("fave.setTags", params))

    async def track_page_interaction(
        self, user_id: Optional[int] = None, group_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """fave.trackPageInteraction method
        :param user_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("fave.trackPageInteraction", params)
        )



from typing import Optional, List

from vkbottle_types.responses import docs, base
from .base_category import BaseCategory


class DocsCategory(BaseCategory):
    async def add(
        self, owner_id: int, doc_id: int, access_key: Optional[str] = None, **kwargs
    ) -> docs.AddResponseModel:
        """Copies a document to a user's or community's document list.
        :param owner_id: ID of the user or community that owns the document. Use a negative value to designate a community ID.
        :param doc_id: Document ID.
        :param access_key: Access key. This parameter is required if 'access_key' was returned with the document's data.
        """

        params = self.get_set_params(locals())
        return docs.AddResponse(**await self.api.request("docs.add", params))

    async def delete(
        self, owner_id: int, doc_id: int, **kwargs
    ) -> base.OkResponseModel:
        """Deletes a user or community document.
        :param owner_id: ID of the user or community that owns the document. Use a negative value to designate a community ID.
        :param doc_id: Document ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("docs.delete", params))

    async def edit(
        self,
        owner_id: int,
        doc_id: int,
        title: Optional[str] = None,
        tags: Optional[List[str]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Edits a document.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param doc_id: Document ID.
        :param title: Document title.
        :param tags: Document tags.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("docs.edit", params))

    async def get(
        self,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        type: Optional[int] = None,
        owner_id: Optional[int] = None,
        return_tags: Optional[bool] = None,
        **kwargs
    ) -> docs.GetResponseModel:
        """Returns detailed information about user or community documents.
        :param count: Number of documents to return. By default, all documents.
        :param offset: Offset needed to return a specific subset of documents.
        :param type:
        :param owner_id: ID of the user or community that owns the documents. Use a negative value to designate a community ID.
        :param return_tags:
        """

        params = self.get_set_params(locals())
        return docs.GetResponse(**await self.api.request("docs.get", params))

    async def get_by_id(
        self, docs: List[str], return_tags: Optional[bool] = None, **kwargs
    ) -> docs.GetByIdResponseModel:
        """Returns information about documents by their IDs.
        :param docs: Document IDs. Example: , "66748_91488,66748_91455",
        :param return_tags:
        """

        params = self.get_set_params(locals())
        return docs.GetByIdResponse(**await self.api.request("docs.getById", params))

    async def get_messages_upload_server(
        self, type: Optional[str] = None, peer_id: Optional[int] = None, **kwargs
    ) -> base.GetUploadServerResponseModel:
        """Returns the server address for document upload.
        :param type: Document type.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        """

        params = self.get_set_params(locals())
        return base.GetUploadServerResponse(
            **await self.api.request("docs.getMessagesUploadServer", params)
        )

    async def get_types(self, owner_id: int, **kwargs) -> docs.GetTypesResponseModel:
        """Returns documents types available for current user.
        :param owner_id: ID of the user or community that owns the documents. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        return docs.GetTypesResponse(**await self.api.request("docs.getTypes", params))

    async def get_upload_server(
        self, group_id: Optional[int] = None, **kwargs
    ) -> docs.GetUploadServerModel:
        """Returns the server address for document upload.
        :param group_id: Community ID (if the document will be uploaded to the community).
        """

        params = self.get_set_params(locals())
        return docs.GetUploadServer(
            **await self.api.request("docs.getUploadServer", params)
        )

    async def get_wall_upload_server(
        self, group_id: Optional[int] = None, **kwargs
    ) -> base.GetUploadServerResponseModel:
        """Returns the server address for document upload onto a user's or community's wall.
        :param group_id: Community ID (if the document will be uploaded to the community).
        """

        params = self.get_set_params(locals())
        return base.GetUploadServerResponse(
            **await self.api.request("docs.getWallUploadServer", params)
        )

    async def save(
        self,
        file: str,
        title: Optional[str] = None,
        tags: Optional[str] = None,
        return_tags: Optional[bool] = None,
        **kwargs
    ) -> docs.SaveResponseModel:
        """Saves a document after [vk.com/dev/upload_files_2|uploading it to a server].
        :param file: This parameter is returned when the file is [vk.com/dev/upload_files_2|uploaded to the server].
        :param title: Document title.
        :param tags: Document tags.
        :param return_tags:
        """

        params = self.get_set_params(locals())
        return docs.SaveResponse(**await self.api.request("docs.save", params))

    async def search(
        self,
        q: str,
        search_own: Optional[bool] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        return_tags: Optional[bool] = None,
        **kwargs
    ) -> docs.SearchResponseModel:
        """Returns a list of documents matching the search criteria.
        :param q: Search query string.
        :param search_own:
        :param count: Number of results to return.
        :param offset: Offset needed to return a specific subset of results.
        :param return_tags:
        """

        params = self.get_set_params(locals())
        return docs.SearchResponse(**await self.api.request("docs.search", params))



from typing import Optional

from .base_response import BaseResponse


class RestoreResponse(BaseResponse):
    response: Optional["RestoreResponseModel"] = None


class RestoreResponseModel(BaseResponse):
    success: Optional[int] = None
    sid: Optional[str] = None


RestoreResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    OrdersAmount,
    OrdersOrder,
    OrdersSubscription,
    BaseBoolInt,
)
from .base_response import BaseResponse


class CancelSubscriptionResponse(BaseResponse):
    response: Optional["CancelSubscriptionResponseModel"] = None


class ChangeStateResponse(BaseResponse):
    response: Optional["ChangeStateResponseModel"] = None


class GetAmountResponse(BaseResponse):
    response: Optional["GetAmountResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetUserSubscriptionByIdResponse(BaseResponse):
    response: Optional["GetUserSubscriptionByIdResponseModel"] = None


class GetUserSubscriptionsResponse(BaseResponse):
    response: Optional["GetUserSubscriptionsResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class UpdateSubscriptionResponse(BaseResponse):
    response: Optional["UpdateSubscriptionResponseModel"] = None


CancelSubscriptionResponseModel = Optional[BaseBoolInt]

ChangeStateResponseModel = str

GetAmountResponseModel = Optional[OrdersAmount]

GetByIdResponseModel = List[OrdersOrder]

GetUserSubscriptionByIdResponseModel = Optional[OrdersSubscription]


class GetUserSubscriptionsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["OrdersSubscription"]] = None


GetResponseModel = List[OrdersOrder]

UpdateSubscriptionResponseModel = Optional[BaseBoolInt]


CancelSubscriptionResponse.update_forward_refs()
ChangeStateResponse.update_forward_refs()
GetAmountResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetUserSubscriptionByIdResponse.update_forward_refs()
GetUserSubscriptionsResponse.update_forward_refs()
GetResponse.update_forward_refs()
UpdateSubscriptionResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.responses import prettyCards
from .base_category import BaseCategory


class PrettyCardsCategory(BaseCategory):
    async def create(
        self,
        owner_id: int,
        photo: str,
        title: str,
        link: str,
        price: Optional[str] = None,
        price_old: Optional[str] = None,
        button: Optional[str] = None,
        **kwargs
    ) -> prettyCards.CreateResponseModel:
        """prettyCards.create method
        :param owner_id:
        :param photo:
        :param title:
        :param link:
        :param price:
        :param price_old:
        :param button:
        """

        params = self.get_set_params(locals())
        return prettyCards.CreateResponse(
            **await self.api.request("prettyCards.create", params)
        )

    async def delete(
        self, owner_id: int, card_id: int, **kwargs
    ) -> prettyCards.DeleteResponseModel:
        """prettyCards.delete method
        :param owner_id:
        :param card_id:
        """

        params = self.get_set_params(locals())
        return prettyCards.DeleteResponse(
            **await self.api.request("prettyCards.delete", params)
        )

    async def edit(
        self,
        owner_id: int,
        card_id: int,
        photo: Optional[str] = None,
        title: Optional[str] = None,
        link: Optional[str] = None,
        price: Optional[str] = None,
        price_old: Optional[str] = None,
        button: Optional[str] = None,
        **kwargs
    ) -> prettyCards.EditResponseModel:
        """prettyCards.edit method
        :param owner_id:
        :param card_id:
        :param photo:
        :param title:
        :param link:
        :param price:
        :param price_old:
        :param button:
        """

        params = self.get_set_params(locals())
        return prettyCards.EditResponse(
            **await self.api.request("prettyCards.edit", params)
        )

    async def get(
        self,
        owner_id: int,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> prettyCards.GetResponseModel:
        """prettyCards.get method
        :param owner_id:
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        return prettyCards.GetResponse(
            **await self.api.request("prettyCards.get", params)
        )

    async def get_by_id(
        self, owner_id: int, card_ids: List[int], **kwargs
    ) -> prettyCards.GetByIdResponseModel:
        """prettyCards.getById method
        :param owner_id:
        :param card_ids:
        """

        params = self.get_set_params(locals())
        return prettyCards.GetByIdResponse(
            **await self.api.request("prettyCards.getById", params)
        )

    async def get_upload_url(self, **kwargs) -> prettyCards.GetUploadURLResponseModel:
        """prettyCards.getUploadURL method"""

        params = self.get_set_params(locals())
        return prettyCards.GetUploadURLResponse(
            **await self.api.request("prettyCards.getUploadURL", params)
        )



from typing import Optional

from vkbottle_types.objects import StatusStatus
from .base_response import BaseResponse


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


GetResponseModel = Optional[StatusStatus]

GetResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    GroupsGroupFull,
    VideoSaveResult,
    UsersUserMin,
    WallWallComment,
    VideoVideo,
    VideoVideoFull,
    BaseBoolInt,
    VideoVideoAlbumFull,
)
from .base_response import BaseResponse


class AddAlbumResponse(BaseResponse):
    response: Optional["AddAlbumResponseModel"] = None


class CreateCommentResponse(BaseResponse):
    response: Optional["CreateCommentResponseModel"] = None


class GetAlbumByIdResponse(BaseResponse):
    response: Optional["GetAlbumByIdResponseModel"] = None


class GetAlbumsByVideoExtendedResponse(BaseResponse):
    response: Optional["GetAlbumsByVideoExtendedResponseModel"] = None


class GetAlbumsByVideoResponse(BaseResponse):
    response: Optional["GetAlbumsByVideoResponseModel"] = None


class GetAlbumsExtendedResponse(BaseResponse):
    response: Optional["GetAlbumsExtendedResponseModel"] = None


class GetAlbumsResponse(BaseResponse):
    response: Optional["GetAlbumsResponseModel"] = None


class GetCommentsExtendedResponse(BaseResponse):
    response: Optional["GetCommentsExtendedResponseModel"] = None


class GetCommentsResponse(BaseResponse):
    response: Optional["GetCommentsResponseModel"] = None


class GetExtendedResponse(BaseResponse):
    response: Optional["GetExtendedResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class RestoreCommentResponse(BaseResponse):
    response: Optional["RestoreCommentResponseModel"] = None


class SaveResponse(BaseResponse):
    response: Optional["SaveResponseModel"] = None


class SearchExtendedResponse(BaseResponse):
    response: Optional["SearchExtendedResponseModel"] = None


class SearchResponse(BaseResponse):
    response: Optional["SearchResponseModel"] = None


class AddAlbumResponseModel(BaseResponse):
    album_id: Optional[int] = None


CreateCommentResponseModel = int

GetAlbumByIdResponseModel = Optional[VideoVideoAlbumFull]


class GetAlbumsByVideoExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["VideoVideoAlbumFull"]] = None


GetAlbumsByVideoResponseModel = List[int]


class GetAlbumsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["VideoVideoAlbumFull"]] = None


class GetAlbumsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["VideoVideoAlbumFull"]] = None


class GetCommentsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallComment"]] = None
    profiles: Optional[List["UsersUserMin"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetCommentsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallComment"]] = None


class GetExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["VideoVideoFull"]] = None
    profiles: Optional[List["UsersUserMin"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["VideoVideo"]] = None


RestoreCommentResponseModel = Optional[BaseBoolInt]

SaveResponseModel = Optional[VideoSaveResult]


class SearchExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["VideoVideo"]] = None
    profiles: Optional[List["UsersUserMin"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class SearchResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["VideoVideo"]] = None


AddAlbumResponse.update_forward_refs()
CreateCommentResponse.update_forward_refs()
GetAlbumByIdResponse.update_forward_refs()
GetAlbumsByVideoExtendedResponse.update_forward_refs()
GetAlbumsByVideoResponse.update_forward_refs()
GetAlbumsExtendedResponse.update_forward_refs()
GetAlbumsResponse.update_forward_refs()
GetCommentsExtendedResponse.update_forward_refs()
GetCommentsResponse.update_forward_refs()
GetExtendedResponse.update_forward_refs()
GetResponse.update_forward_refs()
RestoreCommentResponse.update_forward_refs()
SaveResponse.update_forward_refs()
SearchExtendedResponse.update_forward_refs()
SearchResponse.update_forward_refs()



import typing

if typing.TYPE_CHECKING:
    from vkbottle import API

# from typing import NamedTuple
# RequestMethod = NamedTuple("RequestMethod", [("base_name", str), ("method_name", str), ("params", dict)])


class BaseCategory:
    def __init__(self, api: "API"):
        self.api = api

    @classmethod
    def get_set_params(cls, params: dict, **kwargs) -> dict:
        exclude_params = params.copy().update(params["kwargs"])
        exclude_params.pop("kwargs")
        return {
            k if not k.endswith("_", **kwargs) else k[:-1]: v
            for k, v in exclude_params.keys()
            if k != "self" and v is not None
        }

    @classmethod
    def construct_api(cls, api: "API", **kwargs) -> "BaseCategory":
        cls.api = api
        return cls



from typing import Optional, List

from vkbottle_types.objects import (
    PhotosPhotoTag,
    PhotosPhotoXtrTagInfo,
    GroupsGroupFull,
    PhotosCommentXtrPid,
    PhotosPhotoXtrRealOffset,
    WallWallComment,
    PhotosPhotoUpload,
    PhotosPhoto,
    PhotosPhotoFullXtrRealOffset,
    UsersUserFull,
    PhotosPhotoAlbumFull,
    PhotosPhotoFull,
    BaseBoolInt,
    BaseImage,
    BaseUploadServer,
)
from .base_response import BaseResponse


class CopyResponse(BaseResponse):
    response: Optional["CopyResponseModel"] = None


class CreateAlbumResponse(BaseResponse):
    response: Optional["CreateAlbumResponseModel"] = None


class CreateCommentResponse(BaseResponse):
    response: Optional["CreateCommentResponseModel"] = None


class DeleteCommentResponse(BaseResponse):
    response: Optional["DeleteCommentResponseModel"] = None


class GetAlbumsCountResponse(BaseResponse):
    response: Optional["GetAlbumsCountResponseModel"] = None


class GetAlbumsResponse(BaseResponse):
    response: Optional["GetAlbumsResponseModel"] = None


class GetAllCommentsResponse(BaseResponse):
    response: Optional["GetAllCommentsResponseModel"] = None


class GetAllExtendedResponse(BaseResponse):
    response: Optional["GetAllExtendedResponseModel"] = None


class GetAllResponse(BaseResponse):
    response: Optional["GetAllResponseModel"] = None


class GetByIdExtendedResponse(BaseResponse):
    response: Optional["GetByIdExtendedResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetCommentsExtendedResponse(BaseResponse):
    response: Optional["GetCommentsExtendedResponseModel"] = None


class GetCommentsResponse(BaseResponse):
    response: Optional["GetCommentsResponseModel"] = None


class GetMarketUploadServerResponse(BaseResponse):
    response: Optional["GetMarketUploadServerResponseModel"] = None


class GetMessagesUploadServerResponse(BaseResponse):
    response: Optional["GetMessagesUploadServerResponseModel"] = None


class GetNewTagsResponse(BaseResponse):
    response: Optional["GetNewTagsResponseModel"] = None


class GetTagsResponse(BaseResponse):
    response: Optional["GetTagsResponseModel"] = None


class GetUploadServerResponse(BaseResponse):
    response: Optional["GetUploadServerResponseModel"] = None


class GetUserPhotosExtendedResponse(BaseResponse):
    response: Optional["GetUserPhotosExtendedResponseModel"] = None


class GetUserPhotosResponse(BaseResponse):
    response: Optional["GetUserPhotosResponseModel"] = None


class GetWallUploadServerResponse(BaseResponse):
    response: Optional["GetWallUploadServerResponseModel"] = None


class GetExtendedResponse(BaseResponse):
    response: Optional["GetExtendedResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class PutTagResponse(BaseResponse):
    response: Optional["PutTagResponseModel"] = None


class RestoreCommentResponse(BaseResponse):
    response: Optional["RestoreCommentResponseModel"] = None


class SaveMarketAlbumPhotoResponse(BaseResponse):
    response: Optional["SaveMarketAlbumPhotoResponseModel"] = None


class SaveMarketPhotoResponse(BaseResponse):
    response: Optional["SaveMarketPhotoResponseModel"] = None


class SaveMessagesPhotoResponse(BaseResponse):
    response: Optional["SaveMessagesPhotoResponseModel"] = None


class SaveOwnerCoverPhotoResponse(BaseResponse):
    response: Optional["SaveOwnerCoverPhotoResponseModel"] = None


class SaveOwnerPhotoResponse(BaseResponse):
    response: Optional["SaveOwnerPhotoResponseModel"] = None


class SaveWallPhotoResponse(BaseResponse):
    response: Optional["SaveWallPhotoResponseModel"] = None


class SaveResponse(BaseResponse):
    response: Optional["SaveResponseModel"] = None


class SearchResponse(BaseResponse):
    response: Optional["SearchResponseModel"] = None


CopyResponseModel = int

CreateAlbumResponseModel = Optional[PhotosPhotoAlbumFull]

CreateCommentResponseModel = int

DeleteCommentResponseModel = Optional[BaseBoolInt]


GetAlbumsCountResponseModel = int


class GetAlbumsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhotoAlbumFull"]] = None


class GetAllCommentsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosCommentXtrPid"]] = None


class GetAllExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhotoFullXtrRealOffset"]] = None
    more: Optional["BaseBoolInt"] = None


class GetAllResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhotoXtrRealOffset"]] = None
    more: Optional["BaseBoolInt"] = None


GetByIdExtendedResponseModel = List[PhotosPhotoFull]

GetByIdResponseModel = List[PhotosPhoto]


class GetCommentsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    real_offset: Optional[int] = None
    items: Optional[List["WallWallComment"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetCommentsResponseModel(BaseResponse):
    count: Optional[int] = None
    real_offset: Optional[int] = None
    items: Optional[List["WallWallComment"]] = None


GetMarketUploadServerResponseModel = Optional[BaseUploadServer]

GetMessagesUploadServerResponseModel = Optional[PhotosPhotoUpload]


class GetNewTagsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhotoXtrTagInfo"]] = None


GetTagsResponseModel = List[PhotosPhotoTag]

GetUploadServerResponseModel = Optional[PhotosPhotoUpload]


class GetUserPhotosExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhotoFull"]] = None


class GetUserPhotosResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhoto"]] = None


GetWallUploadServerResponseModel = Optional[PhotosPhotoUpload]


class GetExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhotoFull"]] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhoto"]] = None


PutTagResponseModel = int

RestoreCommentResponseModel = Optional[BaseBoolInt]

SaveMarketAlbumPhotoResponseModel = List[PhotosPhoto]

SaveMarketPhotoResponseModel = List[PhotosPhoto]

SaveMessagesPhotoResponseModel = List[PhotosPhoto]

SaveOwnerCoverPhotoResponseModel = List[BaseImage]


class SaveOwnerPhotoResponseModel(BaseResponse):
    photo_hash: Optional[str] = None
    photo_src: Optional[str] = None
    photo_src_big: Optional[str] = None
    photo_src_small: Optional[str] = None
    saved: Optional[int] = None
    post_id: Optional[int] = None


SaveWallPhotoResponseModel = List[PhotosPhoto]

SaveResponseModel = List[PhotosPhoto]


class SearchResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PhotosPhoto"]] = None


CopyResponse.update_forward_refs()
CreateAlbumResponse.update_forward_refs()
CreateCommentResponse.update_forward_refs()
DeleteCommentResponse.update_forward_refs()
GetAlbumsCountResponse.update_forward_refs()
GetAlbumsResponse.update_forward_refs()
GetAllCommentsResponse.update_forward_refs()
GetAllExtendedResponse.update_forward_refs()
GetAllResponse.update_forward_refs()
GetByIdExtendedResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetCommentsExtendedResponse.update_forward_refs()
GetCommentsResponse.update_forward_refs()
GetMarketUploadServerResponse.update_forward_refs()
GetMessagesUploadServerResponse.update_forward_refs()
GetNewTagsResponse.update_forward_refs()
GetTagsResponse.update_forward_refs()
GetUploadServerResponse.update_forward_refs()
GetUserPhotosExtendedResponse.update_forward_refs()
GetUserPhotosResponse.update_forward_refs()
GetWallUploadServerResponse.update_forward_refs()
GetExtendedResponse.update_forward_refs()
GetResponse.update_forward_refs()
PutTagResponse.update_forward_refs()
RestoreCommentResponse.update_forward_refs()
SaveMarketAlbumPhotoResponse.update_forward_refs()
SaveMarketPhotoResponse.update_forward_refs()
SaveMessagesPhotoResponse.update_forward_refs()
SaveOwnerCoverPhotoResponse.update_forward_refs()
SaveOwnerPhotoResponse.update_forward_refs()
SaveWallPhotoResponse.update_forward_refs()
SaveResponse.update_forward_refs()
SearchResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.responses import streaming, base
from .base_category import BaseCategory


class StreamingCategory(BaseCategory):
    async def get_server_url(self, **kwargs) -> streaming.GetServerUrlResponseModel:
        """Allows to receive data for the connection to Streaming API."""

        params = self.get_set_params(locals())
        return streaming.GetServerUrlResponse(
            **await self.api.request("streaming.getServerUrl", params)
        )

    async def set_settings(
        self, monthly_tier: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """streaming.setSettings method
        :param monthly_tier:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("streaming.setSettings", params)
        )



from typing import Optional, List

from vkbottle_types.objects import (
    PagesWikipageFull,
    PagesWikipageHistory,
    PagesWikipage,
)
from .base_response import BaseResponse


class GetHistoryResponse(BaseResponse):
    response: Optional["GetHistoryResponseModel"] = None


class GetTitlesResponse(BaseResponse):
    response: Optional["GetTitlesResponseModel"] = None


class GetVersionResponse(BaseResponse):
    response: Optional["GetVersionResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class ParseWikiResponse(BaseResponse):
    response: Optional["ParseWikiResponseModel"] = None


class SaveAccessResponse(BaseResponse):
    response: Optional["SaveAccessResponseModel"] = None


class SaveResponse(BaseResponse):
    response: Optional["SaveResponseModel"] = None


GetHistoryResponseModel = List[PagesWikipageHistory]

GetTitlesResponseModel = List[PagesWikipage]

GetVersionResponseModel = Optional[PagesWikipageFull]

GetResponseModel = Optional[PagesWikipageFull]

ParseWikiResponseModel = str

SaveAccessResponseModel = int

SaveResponseModel = int

GetHistoryResponse.update_forward_refs()
GetTitlesResponse.update_forward_refs()
GetVersionResponse.update_forward_refs()
GetResponse.update_forward_refs()
ParseWikiResponse.update_forward_refs()
SaveAccessResponse.update_forward_refs()
SaveResponse.update_forward_refs()



import typing
from typing import Optional, List

from vkbottle_types.responses import users, base
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import users as objects_users


class UsersCategory(BaseCategory):
    async def get(
        self,
        user_ids: Optional[List[int]] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        **kwargs
    ) -> users.GetResponseModel:
        """Returns detailed information on users.
        :param user_ids: User IDs or screen names ('screen_name'). By default, current user ID.
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'contacts', 'education', 'online', 'counters', 'relation', 'last_seen', 'activity', 'can_write_private_message', 'can_see_all_posts', 'can_post', 'universities', 'can_invite_to_chats'
        :param name_case: Case for declension of user name and surname: 'nom' — nominative (default), 'gen' — genitive , 'dat' — dative, 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        """

        params = self.get_set_params(locals())
        return users.GetResponse(**await self.api.request("users.get", params))

    async def get_followers(
        self,
        user_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        **kwargs
    ) -> users.GetFollowersResponseModel:
        """Returns a list of IDs of followers of the user in question, sorted by date added, most recent first.
        :param user_id: User ID.
        :param offset: Offset needed to return a specific subset of followers.
        :param count: Number of followers to return.
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online'.
        :param name_case: Case for declension of user name and surname: 'nom' — nominative (default), 'gen' — genitive , 'dat' — dative, 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        """

        params = self.get_set_params(locals())
        return users.GetFollowersResponse(
            **await self.api.request("users.getFollowers", params)
        )

    async def get_subscriptions(
        self,
        user_id: Optional[int] = None,
        extended: Optional[bool] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        **kwargs
    ) -> users.GetSubscriptionsExtendedResponseModel:
        """Returns a list of IDs of users and communities followed by the user.
        :param user_id: User ID.
        :param extended: '1' — to return a combined list of users and communities, '0' — to return separate lists of users and communities (default)
        :param offset: Offset needed to return a specific subset of subscriptions.
        :param count: Number of users and communities to return.
        :param fields:
        """

        params = self.get_set_params(locals())
        return users.GetSubscriptionsExtendedResponse(
            **await self.api.request("users.getSubscriptions", params)
        )

    async def report(
        self, user_id: int, type: str, comment: Optional[str] = None, **kwargs
    ) -> base.OkResponseModel:
        """Reports (submits a complain about, **kwargs) a user.
        :param user_id: ID of the user about whom a complaint is being made.
        :param type: Type of complaint: 'porn' – pornography, 'spam' – spamming, 'insult' – abusive behavior, 'advertisement' – disruptive advertisements
        :param comment: Comment describing the complaint.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("users.report", params))

    async def search(
        self,
        q: Optional[str] = None,
        sort: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        city: Optional[int] = None,
        country: Optional[int] = None,
        hometown: Optional[str] = None,
        university_country: Optional[int] = None,
        university: Optional[int] = None,
        university_year: Optional[int] = None,
        university_faculty: Optional[int] = None,
        university_chair: Optional[int] = None,
        sex: Optional[int] = None,
        status: Optional[int] = None,
        age_from: Optional[int] = None,
        age_to: Optional[int] = None,
        birth_day: Optional[int] = None,
        birth_month: Optional[int] = None,
        birth_year: Optional[int] = None,
        online: Optional[bool] = None,
        has_photo: Optional[bool] = None,
        school_country: Optional[int] = None,
        school_city: Optional[int] = None,
        school_class: Optional[int] = None,
        school: Optional[int] = None,
        school_year: Optional[int] = None,
        religion: Optional[str] = None,
        company: Optional[str] = None,
        position: Optional[str] = None,
        group_id: Optional[int] = None,
        from_list: Optional[List[str]] = None,
        **kwargs
    ) -> users.SearchResponseModel:
        """Returns a list of users matching the search criteria.
        :param q: Search query string (e.g., 'Vasya Babich').
        :param sort: Sort order: '1' — by date registered, '0' — by rating
        :param offset: Offset needed to return a specific subset of users.
        :param count: Number of users to return.
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online',
        :param city: City ID.
        :param country: Country ID.
        :param hometown: City name in a string.
        :param university_country: ID of the country where the user graduated.
        :param university: ID of the institution of higher education.
        :param university_year: Year of graduation from an institution of higher education.
        :param university_faculty: Faculty ID.
        :param university_chair: Chair ID.
        :param sex: '1' — female, '2' — male, '0' — any (default)
        :param status: Relationship status: '1' — Not married, '2' — In a relationship, '3' — Engaged, '4' — Married, '5' — It's complicated, '6' — Actively searching, '7' — In love
        :param age_from: Minimum age.
        :param age_to: Maximum age.
        :param birth_day: Day of birth.
        :param birth_month: Month of birth.
        :param birth_year: Year of birth.
        :param online: '1' — online only, '0' — all users
        :param has_photo: '1' — with photo only, '0' — all users
        :param school_country: ID of the country where users finished school.
        :param school_city: ID of the city where users finished school.
        :param school_class:
        :param school: ID of the school.
        :param school_year: School graduation year.
        :param religion: Users' religious affiliation.
        :param company: Name of the company where users work.
        :param position: Job position.
        :param group_id: ID of a community to search in communities.
        :param from_list:
        """

        params = self.get_set_params(locals())
        return users.SearchResponse(**await self.api.request("users.search", params))



from vkbottle_types.responses import base
from .base_category import BaseCategory


class AppWidgetsCategory(BaseCategory):
    async def update(self, code: str, type: str, **kwargs) -> base.OkResponseModel:
        """Allows to update community app widget
        :param code:
        :param type:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("appWidgets.update", params))



from typing import Optional, List

from vkbottle_types.objects import StorageValue
from .base_response import BaseResponse


class GetKeysResponse(BaseResponse):
    response: Optional["GetKeysResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class GetV5110Response(BaseResponse):
    response: Optional["GetV5110ResponseModel"] = None


class GetWithKeysResponse(BaseResponse):
    response: Optional["GetWithKeysResponseModel"] = None


GetKeysResponseModel = List[str]

GetResponseModel = str

GetV5110ResponseModel = List[StorageValue]

GetWithKeysResponseModel = List[StorageValue]

GetKeysResponse.update_forward_refs()
GetResponse.update_forward_refs()
GetV5110Response.update_forward_refs()
GetWithKeysResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    SecureTokenChecked,
    SecureTransaction,
    SecureLevel,
    SecureSmsNotification,
)
from .base_response import BaseResponse


class CheckTokenResponse(BaseResponse):
    response: Optional["CheckTokenResponseModel"] = None


class GetAppBalanceResponse(BaseResponse):
    response: Optional["GetAppBalanceResponseModel"] = None


class GetSMSHistoryResponse(BaseResponse):
    response: Optional["GetSMSHistoryResponseModel"] = None


class GetTransactionsHistoryResponse(BaseResponse):
    response: Optional["GetTransactionsHistoryResponseModel"] = None


class GetUserLevelResponse(BaseResponse):
    response: Optional["GetUserLevelResponseModel"] = None


class GiveEventStickerResponse(BaseResponse):
    response: Optional["GiveEventStickerResponseModel"] = None


class SendNotificationResponse(BaseResponse):
    response: Optional["SendNotificationResponseModel"] = None


CheckTokenResponseModel = Optional[SecureTokenChecked]

GetAppBalanceResponseModel = int

GetSMSHistoryResponseModel = List[SecureSmsNotification]

GetTransactionsHistoryResponseModel = List[SecureTransaction]

GetUserLevelResponseModel = List[SecureLevel]


class GiveEventStickerResponseModel(BaseResponse):
    user_id: Optional[int] = None
    status: Optional[str] = None


SendNotificationResponseModel = List[int]


CheckTokenResponse.update_forward_refs()
GetAppBalanceResponse.update_forward_refs()
GetSMSHistoryResponse.update_forward_refs()
GetTransactionsHistoryResponse.update_forward_refs()
GetUserLevelResponse.update_forward_refs()
GiveEventStickerResponse.update_forward_refs()
SendNotificationResponse.update_forward_refs()



import typing
from typing import Optional, List

from vkbottle_types.responses import base, stories as stories_responses
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import base as objects_base


class StoriesCategory(BaseCategory):
    async def ban_owner(self, owners_ids: List[int], **kwargs) -> base.OkResponseModel:
        """Allows to hide stories from chosen sources from current user's feed.
        :param owners_ids: List of sources IDs
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("stories.banOwner", params))

    async def delete(
        self, owner_id: int, story_id: int, **kwargs
    ) -> base.OkResponseModel:
        """Allows to delete story.
        :param owner_id: Story owner's ID. Current user id is used by default.
        :param story_id: Story ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("stories.delete", params))

    async def get(
        self,
        owner_id: Optional[int] = None,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> stories_responses.GetV5113ResponseModel:
        """Returns stories available for current user.
        :param owner_id: Owner ID.
        :param extended: '1' — to return additional fields for users and communities. Default value is 0.
        :param fields:
        """

        params = self.get_set_params(locals())
        return stories_responses.GetV5113Response(
            **await self.api.request("stories.get", params)
        )

    async def get_banned(
        self,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> stories_responses.GetBannedExtendedResponseModel:
        """Returns list of sources hidden from current user's feed.
        :param extended: '1' — to return additional fields for users and communities. Default value is 0.
        :param fields: Additional fields to return
        """

        params = self.get_set_params(locals())
        return stories_responses.GetBannedExtendedResponse(
            **await self.api.request("stories.getBanned", params)
        )

    async def get_by_id(
        self,
        stories: List[str],
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> stories_responses.GetByIdExtendedResponseModel:
        """Returns story by its ID.
        :param stories: Stories IDs separated by commas. Use format {owner_id}+'_'+{story_id}, for example, 12345_54331.
        :param extended: '1' — to return additional fields for users and communities. Default value is 0.
        :param fields: Additional fields to return
        """

        params = self.get_set_params(locals())
        return stories_responses.GetByIdExtendedResponse(
            **await self.api.request("stories.getById", params)
        )

    async def get_photo_upload_server(
        self,
        add_to_news: Optional[bool] = None,
        user_ids: Optional[List[int]] = None,
        reply_to_story: Optional[str] = None,
        link_text: Optional[str] = None,
        link_url: Optional[str] = None,
        group_id: Optional[int] = None,
        clickable_stickers: Optional[str] = None,
        **kwargs
    ) -> stories_responses.GetPhotoUploadServerResponseModel:
        """Returns URL for uploading a story with photo.
        :param add_to_news: 1 — to add the story to friend's feed.
        :param user_ids: List of users IDs who can see the story.
        :param reply_to_story: ID of the story to reply with the current.
        :param link_text: Link text (for community's stories only).
        :param link_url: Link URL. Internal links on https://vk.com only.
        :param group_id: ID of the community to upload the story (should be verified or with the "fire" icon).
        :param clickable_stickers:
        """

        params = self.get_set_params(locals())
        return stories_responses.GetPhotoUploadServerResponse(
            **await self.api.request("stories.getPhotoUploadServer", params)
        )

    async def get_replies(
        self,
        owner_id: int,
        story_id: int,
        access_key: Optional[str] = None,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> stories_responses.GetV5113ResponseModel:
        """Returns replies to the story.
        :param owner_id: Story owner ID.
        :param story_id: Story ID.
        :param access_key: Access key for the private object.
        :param extended: '1' — to return additional fields for users and communities. Default value is 0.
        :param fields: Additional fields to return
        """

        params = self.get_set_params(locals())
        return stories_responses.GetV5113Response(
            **await self.api.request("stories.getReplies", params)
        )

    async def get_stats(
        self, owner_id: int, story_id: int, **kwargs
    ) -> stories_responses.GetStatsResponseModel:
        """Returns stories available for current user.
        :param owner_id: Story owner ID.
        :param story_id: Story ID.
        """

        params = self.get_set_params(locals())
        return stories_responses.GetStatsResponse(
            **await self.api.request("stories.getStats", params)
        )

    async def get_video_upload_server(
        self,
        add_to_news: Optional[bool] = None,
        user_ids: Optional[List[int]] = None,
        reply_to_story: Optional[str] = None,
        link_text: Optional[str] = None,
        link_url: Optional[str] = None,
        group_id: Optional[int] = None,
        clickable_stickers: Optional[str] = None,
        **kwargs
    ) -> stories_responses.GetVideoUploadServerResponseModel:
        """Allows to receive URL for uploading story with video.
        :param add_to_news: 1 — to add the story to friend's feed.
        :param user_ids: List of users IDs who can see the story.
        :param reply_to_story: ID of the story to reply with the current.
        :param link_text: Link text (for community's stories only).
        :param link_url: Link URL. Internal links on https://vk.com only.
        :param group_id: ID of the community to upload the story (should be verified or with the "fire" icon).
        :param clickable_stickers:
        """

        params = self.get_set_params(locals())
        return stories_responses.GetVideoUploadServerResponse(
            **await self.api.request("stories.getVideoUploadServer", params)
        )

    async def get_viewers(
        self,
        owner_id: int,
        story_id: int,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> stories_responses.GetViewersExtendedV5115ResponseModel:
        """Returns a list of story viewers.
        :param owner_id: Story owner ID.
        :param story_id: Story ID.
        :param count: Maximum number of results.
        :param offset: Offset needed to return a specific subset of results.
        :param extended: '1' — to return detailed information about photos
        """

        params = self.get_set_params(locals())
        return stories_responses.GetViewersExtendedV5115Response(
            **await self.api.request("stories.getViewers", params)
        )

    async def hide_all_replies(
        self, owner_id: int, group_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Hides all replies in the last 24 hours from the user to current user's stories.
        :param owner_id: ID of the user whose replies should be hidden.
        :param group_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("stories.hideAllReplies", params)
        )

    async def hide_reply(
        self, owner_id: int, story_id: int, **kwargs
    ) -> base.OkResponseModel:
        """Hides the reply to the current user's story.
        :param owner_id: ID of the user whose replies should be hidden.
        :param story_id: Story ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("stories.hideReply", params))

    async def search(
        self,
        q: Optional[str] = None,
        place_id: Optional[int] = None,
        latitude: Optional[float] = None,
        longitude: Optional[float] = None,
        radius: Optional[int] = None,
        mentioned_id: Optional[int] = None,
        count: Optional[int] = None,
        extended: Optional[bool] = None,
        fields: Optional[List[str]] = None,
        **kwargs
    ) -> stories_responses.GetV5113ResponseModel:
        """stories.search method
        :param q:
        :param place_id:
        :param latitude:
        :param longitude:
        :param radius:
        :param mentioned_id:
        :param count:
        :param extended:
        :param fields:
        """

        params = self.get_set_params(locals())
        return stories_responses.GetV5113Response(
            **await self.api.request("stories.search", params)
        )

    async def unban_owner(
        self, owners_ids: List[int], **kwargs
    ) -> base.OkResponseModel:
        """Allows to show stories from hidden sources in current user's feed.
        :param owners_ids: List of hidden sources to show stories from.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("stories.unbanOwner", params))



from typing import Optional, List

from vkbottle_types.responses import orders
from .base_category import BaseCategory


class OrdersCategory(BaseCategory):
    async def cancel_subscription(
        self,
        user_id: int,
        subscription_id: int,
        pending_cancel: Optional[bool] = None,
        **kwargs
    ) -> orders.CancelSubscriptionResponseModel:
        """orders.cancelSubscription method
        :param user_id:
        :param subscription_id:
        :param pending_cancel:
        """

        params = self.get_set_params(locals())
        return orders.CancelSubscriptionResponse(
            **await self.api.request("orders.cancelSubscription", params)
        )

    async def change_state(
        self,
        order_id: int,
        action: str,
        app_order_id: Optional[int] = None,
        test_mode: Optional[bool] = None,
        **kwargs
    ) -> orders.ChangeStateResponseModel:
        """Changes order status.
        :param order_id: order ID.
        :param action: action to be done with the order. Available actions: *cancel — to cancel unconfirmed order. *charge — to confirm unconfirmed order. Applies only if processing of [vk.com/dev/payments_status|order_change_state] notification failed. *refund — to cancel confirmed order.
        :param app_order_id: internal ID of the order in the application.
        :param test_mode: if this parameter is set to 1, this method returns a list of test mode orders. By default — 0.
        """

        params = self.get_set_params(locals())
        return orders.ChangeStateResponse(
            **await self.api.request("orders.changeState", params)
        )

    async def get(
        self,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        test_mode: Optional[bool] = None,
        **kwargs
    ) -> orders.GetResponseModel:
        """Returns a list of orders.
        :param offset:
        :param count: number of returned orders.
        :param test_mode: if this parameter is set to 1, this method returns a list of test mode orders. By default — 0.
        """

        params = self.get_set_params(locals())
        return orders.GetResponse(**await self.api.request("orders.get", params))

    async def get_amount(
        self, user_id: int, votes: List[str], **kwargs
    ) -> orders.GetAmountResponseModel:
        """orders.getAmount method
        :param user_id:
        :param votes:
        """

        params = self.get_set_params(locals())
        return orders.GetAmountResponse(
            **await self.api.request("orders.getAmount", params)
        )

    async def get_by_id(
        self,
        order_id: Optional[int] = None,
        order_ids: Optional[List[int]] = None,
        test_mode: Optional[bool] = None,
        **kwargs
    ) -> orders.GetByIdResponseModel:
        """Returns information about orders by their IDs.
        :param order_id: order ID.
        :param order_ids: order IDs (when information about several orders is requested).
        :param test_mode: if this parameter is set to 1, this method returns a list of test mode orders. By default — 0.
        """

        params = self.get_set_params(locals())
        return orders.GetByIdResponse(
            **await self.api.request("orders.getById", params)
        )

    async def get_user_subscription_by_id(
        self, user_id: int, subscription_id: int, **kwargs
    ) -> orders.GetUserSubscriptionByIdResponseModel:
        """orders.getUserSubscriptionById method
        :param user_id:
        :param subscription_id:
        """

        params = self.get_set_params(locals())
        return orders.GetUserSubscriptionByIdResponse(
            **await self.api.request("orders.getUserSubscriptionById", params)
        )

    async def get_user_subscriptions(
        self, user_id: int, **kwargs
    ) -> orders.GetUserSubscriptionsResponseModel:
        """orders.getUserSubscriptions method
        :param user_id:
        """

        params = self.get_set_params(locals())
        return orders.GetUserSubscriptionsResponse(
            **await self.api.request("orders.getUserSubscriptions", params)
        )

    async def update_subscription(
        self, user_id: int, subscription_id: int, price: int, **kwargs
    ) -> orders.UpdateSubscriptionResponseModel:
        """orders.updateSubscription method
        :param user_id:
        :param subscription_id:
        :param price:
        """

        params = self.get_set_params(locals())
        return orders.UpdateSubscriptionResponse(
            **await self.api.request("orders.updateSubscription", params)
        )



from typing import Optional, List

from vkbottle_types.objects import UsersUserMin, BaseBoolInt
from .base_response import BaseResponse


class AddResponse(BaseResponse):
    response: Optional["AddResponseModel"] = None


class DeleteResponse(BaseResponse):
    response: Optional["DeleteResponseModel"] = None


class GetListExtendedResponse(BaseResponse):
    response: Optional["GetListExtendedResponseModel"] = None


class GetListResponse(BaseResponse):
    response: Optional["GetListResponseModel"] = None


class IsLikedResponse(BaseResponse):
    response: Optional["IsLikedResponseModel"] = None


class AddResponseModel(BaseResponse):
    likes: Optional[int] = None


class DeleteResponseModel(BaseResponse):
    likes: Optional[int] = None


class GetListExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["UsersUserMin"]] = None


class GetListResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List[int]] = None


class IsLikedResponseModel(BaseResponse):
    liked: Optional["BaseBoolInt"] = None
    copied: Optional["BaseBoolInt"] = None


AddResponse.update_forward_refs()
DeleteResponse.update_forward_refs()
GetListExtendedResponse.update_forward_refs()
GetListResponse.update_forward_refs()
IsLikedResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    FaveBookmark,
    UsersUserFull,
    GroupsGroup,
    FaveTag,
    FavePage,
)
from .base_response import BaseResponse


class AddTagResponse(BaseResponse):
    response: Optional["AddTagResponseModel"] = None


class GetPagesResponse(BaseResponse):
    response: Optional["GetPagesResponseModel"] = None


class GetTagsResponse(BaseResponse):
    response: Optional["GetTagsResponseModel"] = None


class GetExtendedResponse(BaseResponse):
    response: Optional["GetExtendedResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


AddTagResponseModel = Optional[FaveTag]


class GetPagesResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["FavePage"]] = None


class GetTagsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["FaveTag"]] = None


class GetExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["FaveBookmark"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroup"]] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["FaveBookmark"]] = None


AddTagResponse.update_forward_refs()
GetPagesResponse.update_forward_refs()
GetTagsResponse.update_forward_refs()
GetExtendedResponse.update_forward_refs()
GetResponse.update_forward_refs()



import typing
from typing import Optional, List

from vkbottle_types.responses import friends, base
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import users as objects_users


class FriendsCategory(BaseCategory):
    async def add(
        self,
        user_id: Optional[int] = None,
        text: Optional[str] = None,
        follow: Optional[bool] = None,
        **kwargs
    ) -> friends.AddResponseModel:
        """Approves or creates a friend request.
        :param user_id: ID of the user whose friend request will be approved or to whom a friend request will be sent.
        :param text: Text of the message (up to 500 characters, **kwargs) for the friend request, if any.
        :param follow: '1' to pass an incoming request to followers list.
        """

        params = self.get_set_params(locals())
        return friends.AddResponse(**await self.api.request("friends.add", params))

    async def add_list(
        self, name: str, user_ids: Optional[List[int]] = None, **kwargs
    ) -> friends.AddListResponseModel:
        """Creates a new friend list for the current user.
        :param name: Name of the friend list.
        :param user_ids: IDs of users to be added to the friend list.
        """

        params = self.get_set_params(locals())
        return friends.AddListResponse(
            **await self.api.request("friends.addList", params)
        )

    async def are_friends(
        self,
        user_ids: List[int],
        need_sign: Optional[bool] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> friends.AreFriendsExtendedResponseModel:
        """Checks the current user's friendship status with other specified users.
        :param user_ids: IDs of the users whose friendship status to check.
        :param need_sign: '1' — to return 'sign' field. 'sign' is md5("{id}_{user_id}_{friends_status}_{application_secret}"), where id is current user ID. This field allows to check that data has not been modified by the client. By default: '0'.
        :param extended: Return friend request read_state field
        """

        params = self.get_set_params(locals())
        return friends.AreFriendsExtendedResponse(
            **await self.api.request("friends.areFriends", params)
        )

    async def delete(
        self, user_id: Optional[int] = None, **kwargs
    ) -> friends.DeleteResponseModel:
        """Declines a friend request or deletes a user from the current user's friend list.
        :param user_id: ID of the user whose friend request is to be declined or who is to be deleted from the current user's friend list.
        """

        params = self.get_set_params(locals())
        return friends.DeleteResponse(
            **await self.api.request("friends.delete", params)
        )

    async def delete_all_requests(self, **kwargs) -> base.OkResponseModel:
        """Marks all incoming friend requests as viewed."""

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("friends.deleteAllRequests", params)
        )

    async def delete_list(self, list_id: int, **kwargs) -> base.OkResponseModel:
        """Deletes a friend list of the current user.
        :param list_id: ID of the friend list to delete.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("friends.deleteList", params))

    async def edit(
        self, user_id: int, list_ids: Optional[List[int]] = None, **kwargs
    ) -> base.OkResponseModel:
        """Edits the friend lists of the selected user.
        :param user_id: ID of the user whose friend list is to be edited.
        :param list_ids: IDs of the friend lists to which to add the user.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("friends.edit", params))

    async def edit_list(
        self,
        list_id: int,
        name: Optional[str] = None,
        user_ids: Optional[List[int]] = None,
        add_user_ids: Optional[List[int]] = None,
        delete_user_ids: Optional[List[int]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Edits a friend list of the current user.
        :param list_id: Friend list ID.
        :param name: Name of the friend list.
        :param user_ids: IDs of users in the friend list.
        :param add_user_ids: (Applies if 'user_ids' parameter is not set.), User IDs to add to the friend list.
        :param delete_user_ids: (Applies if 'user_ids' parameter is not set.), User IDs to delete from the friend list.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("friends.editList", params))

    async def get(
        self,
        user_id: Optional[int] = None,
        order: Optional[str] = None,
        list_id: Optional[int] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        ref: Optional[str] = None,
        **kwargs
    ) -> friends.GetResponseModel:
        """Returns a list of user IDs or detailed information about a user's friends.
        :param user_id: User ID. By default, the current user ID.
        :param order: Sort order: , 'name' — by name (enabled only if the 'fields' parameter is used), 'hints' — by rating, similar to how friends are sorted in My friends section, , This parameter is available only for [vk.com/dev/standalone|desktop applications].
        :param list_id: ID of the friend list returned by the [vk.com/dev/friends.getLists|friends.getLists] method to be used as the source. This parameter is taken into account only when the uid parameter is set to the current user ID. This parameter is available only for [vk.com/dev/standalone|desktop applications].
        :param count: Number of friends to return.
        :param offset: Offset needed to return a specific subset of friends.
        :param fields: Profile fields to return. Sample values: 'uid', 'first_name', 'last_name', 'nickname', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'domain', 'has_mobile', 'rate', 'contacts', 'education'.
        :param name_case: Case for declension of user name and surname: , 'nom' — nominative (default, **kwargs) , 'gen' — genitive , 'dat' — dative , 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        :param ref:
        """

        params = self.get_set_params(locals())
        return friends.GetResponse(**await self.api.request("friends.get", params))

    async def get_app_users(self, **kwargs) -> friends.GetAppUsersResponseModel:
        """Returns a list of IDs of the current user's friends who installed the application."""

        params = self.get_set_params(locals())
        return friends.GetAppUsersResponse(
            **await self.api.request("friends.getAppUsers", params)
        )

    async def get_by_phones(
        self,
        phones: Optional[List[str]] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        **kwargs
    ) -> friends.GetByPhonesResponseModel:
        """Returns a list of the current user's friends whose phone numbers, validated or specified in a profile, are in a given list.
        :param phones: List of phone numbers in MSISDN format (maximum 1000). Example: "+79219876543,+79111234567"
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online, counters'.
        """

        params = self.get_set_params(locals())
        return friends.GetByPhonesResponse(
            **await self.api.request("friends.getByPhones", params)
        )

    async def get_lists(
        self,
        user_id: Optional[int] = None,
        return_system: Optional[bool] = None,
        **kwargs
    ) -> friends.GetListsResponseModel:
        """Returns a list of the user's friend lists.
        :param user_id: User ID.
        :param return_system: '1' — to return system friend lists. By default: '0'.
        """

        params = self.get_set_params(locals())
        return friends.GetListsResponse(
            **await self.api.request("friends.getLists", params)
        )

    async def get_mutual(
        self,
        source_uid: Optional[int] = None,
        target_uid: Optional[int] = None,
        target_uids: Optional[List[int]] = None,
        order: Optional[str] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        **kwargs
    ) -> friends.GetMutualResponseModel:
        """Returns a list of user IDs of the mutual friends of two users.
        :param source_uid: ID of the user whose friends will be checked against the friends of the user specified in 'target_uid'.
        :param target_uid: ID of the user whose friends will be checked against the friends of the user specified in 'source_uid'.
        :param target_uids: IDs of the users whose friends will be checked against the friends of the user specified in 'source_uid'.
        :param order: Sort order: 'random' — random order
        :param count: Number of mutual friends to return.
        :param offset: Offset needed to return a specific subset of mutual friends.
        """

        params = self.get_set_params(locals())
        return friends.GetMutualResponse(
            **await self.api.request("friends.getMutual", params)
        )

    async def get_online(
        self,
        user_id: Optional[int] = None,
        list_id: Optional[int] = None,
        online_mobile: Optional[bool] = None,
        order: Optional[str] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        **kwargs
    ) -> friends.GetOnlineResponseModel:
        """Returns a list of user IDs of a user's friends who are online.
        :param user_id: User ID.
        :param list_id: Friend list ID. If this parameter is not set, information about all online friends is returned.
        :param online_mobile: '1' — to return an additional 'online_mobile' field, '0' — (default),
        :param order: Sort order: 'random' — random order
        :param count: Number of friends to return.
        :param offset: Offset needed to return a specific subset of friends.
        """

        params = self.get_set_params(locals())
        return friends.GetOnlineResponse(
            **await self.api.request("friends.getOnline", params)
        )

    async def get_recent(
        self, count: Optional[int] = None, **kwargs
    ) -> friends.GetRecentResponseModel:
        """Returns a list of user IDs of the current user's recently added friends.
        :param count: Number of recently added friends to return.
        """

        params = self.get_set_params(locals())
        return friends.GetRecentResponse(
            **await self.api.request("friends.getRecent", params)
        )

    async def get_requests(
        self,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        extended: Optional[bool] = None,
        need_mutual: Optional[bool] = None,
        out: Optional[bool] = None,
        sort: Optional[int] = None,
        need_viewed: Optional[bool] = None,
        suggested: Optional[bool] = None,
        ref: Optional[str] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        **kwargs
    ) -> friends.GetRequestsExtendedResponseModel:
        """Returns information about the current user's incoming and outgoing friend requests.
        :param offset: Offset needed to return a specific subset of friend requests.
        :param count: Number of friend requests to return (default 100, maximum 1000).
        :param extended: '1' — to return response messages from users who have sent a friend request or, if 'suggested' is set to '1', to return a list of suggested friends
        :param need_mutual: '1' — to return a list of mutual friends (up to 20), if any
        :param out: '1' — to return outgoing requests, '0' — to return incoming requests (default)
        :param sort: Sort order: '1' — by number of mutual friends, '0' — by date
        :param need_viewed:
        :param suggested: '1' — to return a list of suggested friends, '0' — to return friend requests (default)
        :param ref:
        :param fields:
        """

        params = self.get_set_params(locals())
        return friends.GetRequestsExtendedResponse(
            **await self.api.request("friends.getRequests", params)
        )

    async def get_suggestions(
        self,
        filter: Optional[List[str]] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        **kwargs
    ) -> friends.GetSuggestionsResponseModel:
        """Returns a list of profiles of users whom the current user may know.
        :param filter: Types of potential friends to return: 'mutual' — users with many mutual friends , 'contacts' — users found with the [vk.com/dev/account.importContacts|account.importContacts] method , 'mutual_contacts' — users who imported the same contacts as the current user with the [vk.com/dev/account.importContacts|account.importContacts] method
        :param count: Number of suggestions to return.
        :param offset: Offset needed to return a specific subset of suggestions.
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online', 'counters'.
        :param name_case: Case for declension of user name and surname: , 'nom' — nominative (default, **kwargs) , 'gen' — genitive , 'dat' — dative , 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        """

        params = self.get_set_params(locals())
        return friends.GetSuggestionsResponse(
            **await self.api.request("friends.getSuggestions", params)
        )

    async def search(
        self,
        user_id: int,
        q: Optional[str] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> friends.SearchResponseModel:
        """Returns a list of friends matching the search criteria.
        :param user_id: User ID.
        :param q: Search query string (e.g., 'Vasya Babich').
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online',
        :param name_case: Case for declension of user name and surname: 'nom' — nominative (default), 'gen' — genitive , 'dat' — dative, 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        :param offset: Offset needed to return a specific subset of friends.
        :param count: Number of friends to return.
        """

        params = self.get_set_params(locals())
        return friends.SearchResponse(
            **await self.api.request("friends.search", params)
        )



import typing
from typing import Optional, List

from vkbottle_types.objects import (
    GroupsGroupFull,
    GroupsGroup,
    MessagesMessage,
    MessagesPinnedMessage,
    MessagesHistoryAttachment,
    MessagesChatFull,
    MessageChatPreview,
    MessagesLongpollParams,
    MessagesLastActivity,
    MessagesConversation,
    BaseMessageError,
    MessagesConversationWithMessage,
    BaseBoolInt,
    MessagesChatRestrictions,
    MessagesChat,
    UsersUser,
    UsersUserFull,
    MessagesLongpollMessages,
    MessagesConversationMember,
)
from .base_response import BaseResponse


class CreateChatResponse(BaseResponse):
    response: Optional["CreateChatResponseModel"] = None


class DeleteChatPhotoResponse(BaseResponse):
    response: Optional["DeleteChatPhotoResponseModel"] = None


class DeleteConversationResponse(BaseResponse):
    response: Optional["DeleteConversationResponseModel"] = None


class DeleteResponse(BaseResponse):
    response: Optional["DeleteResponseModel"] = None


class EditResponse(BaseResponse):
    response: Optional["EditResponseModel"] = None


class GetByConversationMessageIdResponse(BaseResponse):
    response: Optional["GetByConversationMessageIdResponseModel"] = None


class GetByIdExtendedResponse(BaseResponse):
    response: Optional["GetByIdExtendedResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetChatPreviewResponse(BaseResponse):
    response: Optional["GetChatPreviewResponseModel"] = None


class GetChatChatIdsFieldsResponse(BaseResponse):
    response: Optional["GetChatChatIdsFieldsResponseModel"] = None


class GetChatChatIdsResponse(BaseResponse):
    response: Optional["GetChatChatIdsResponseModel"] = None


class GetChatFieldsResponse(BaseResponse):
    response: Optional["GetChatFieldsResponseModel"] = None


class GetChatResponse(BaseResponse):
    response: Optional["GetChatResponseModel"] = None


class GetConversationMembersResponse(BaseResponse):
    response: Optional["GetConversationMembersResponseModel"] = None


class GetConversationsByIdExtendedResponse(BaseResponse):
    response: Optional["GetConversationsByIdExtendedResponseModel"] = None


class GetConversationsByIdResponse(BaseResponse):
    response: Optional["GetConversationsByIdResponseModel"] = None


class GetConversationsResponse(BaseResponse):
    response: Optional["GetConversationsResponseModel"] = None


class GetHistoryAttachmentsResponse(BaseResponse):
    response: Optional["GetHistoryAttachmentsResponseModel"] = None


class GetHistoryResponse(BaseResponse):
    response: Optional["GetHistoryResponseModel"] = None


class GetInviteLinkResponse(BaseResponse):
    response: Optional["GetInviteLinkResponseModel"] = None


class GetLastActivityResponse(BaseResponse):
    response: Optional["GetLastActivityResponseModel"] = None


class GetLongPollHistoryResponse(BaseResponse):
    response: Optional["GetLongPollHistoryResponseModel"] = None


class GetLongPollServerResponse(BaseResponse):
    response: Optional["GetLongPollServerResponseModel"] = None


class IsMessagesFromGroupAllowedResponse(BaseResponse):
    response: Optional["IsMessagesFromGroupAllowedResponseModel"] = None


class JoinChatByInviteLinkResponse(BaseResponse):
    response: Optional["JoinChatByInviteLinkResponseModel"] = None


class MarkAsImportantResponse(BaseResponse):
    response: Optional["MarkAsImportantResponseModel"] = None


class PinResponse(BaseResponse):
    response: Optional["PinResponseModel"] = None


class SearchConversationsResponse(BaseResponse):
    response: Optional["SearchConversationsResponseModel"] = None


class SearchResponse(BaseResponse):
    response: Optional["SearchResponseModel"] = None


class SendResponse(BaseResponse):
    response: Optional["SendResponseModel"] = None


class SendUserIdsResponse(BaseResponse):
    response: Optional["SendUserIdsResponseModel"] = None


class SetChatPhotoResponse(BaseResponse):
    response: Optional["SetChatPhotoResponseModel"] = None


CreateChatResponseModel = int


class DeleteChatPhotoResponseModel(BaseResponse):
    message_id: Optional[int] = None
    chat: Optional["MessagesChat"] = None


class DeleteConversationResponseModel(BaseResponse):
    last_deleted_id: Optional[int] = None


DeleteResponseModel = typing.Dict[str, int]

EditResponseModel = Optional[BaseBoolInt]


class GetByConversationMessageIdResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesMessage"]] = None


class GetByIdExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesMessage"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetByIdResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesMessage"]] = None


class GetChatPreviewResponseModel(BaseResponse):
    preview: Optional["MessageChatPreview"] = None
    profiles: Optional[List["UsersUserFull"]] = None


GetChatChatIdsFieldsResponseModel = List[MessagesChatFull]

GetChatChatIdsResponseModel = List[MessagesChat]

GetChatFieldsResponseModel = Optional[MessagesChatFull]

GetChatResponseModel = Optional[MessagesChat]


class GetConversationMembersResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesConversationMember"]] = None
    chat_restrictions: Optional["MessagesChatRestrictions"] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetConversationsByIdExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesConversation"]] = None
    profiles: Optional[List["UsersUser"]] = None


class GetConversationsByIdResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesConversation"]] = None


class GetConversationsResponseModel(BaseResponse):
    count: Optional[int] = None
    unread_count: Optional[int] = None
    items: Optional[List["MessagesConversationWithMessage"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetHistoryAttachmentsResponseModel(BaseResponse):
    items: Optional[List["MessagesHistoryAttachment"]] = None
    next_from: Optional[str] = None


class GetHistoryResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesMessage"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetInviteLinkResponseModel(BaseResponse):
    link: Optional[str] = None


GetLastActivityResponseModel = Optional[MessagesLastActivity]


class GetLongPollHistoryResponseModel(BaseResponse):
    history: Optional[List[List[int]]] = None
    groups: Optional[List["GroupsGroup"]] = None
    messages: Optional["MessagesLongpollMessages"] = None
    profiles: Optional[List["UsersUserFull"]] = None
    chats: Optional[List["MessagesChat"]] = None
    new_pts: Optional[int] = None
    more: Optional[bool] = None
    conversations: Optional[List["MessagesConversation"]] = None


GetLongPollServerResponseModel = Optional[MessagesLongpollParams]


class IsMessagesFromGroupAllowedResponseModel(BaseResponse):
    is_allowed: Optional["BaseBoolInt"] = None


class JoinChatByInviteLinkResponseModel(BaseResponse):
    chat_id: Optional[int] = None


MarkAsImportantResponseModel = List[int]

PinResponseModel = Optional[MessagesPinnedMessage]


class SearchConversationsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesConversation"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class SearchResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["MessagesMessage"]] = None


SendResponseModel = int


class SendUserIdsResponseModel(BaseResponse):
    peer_id: Optional[int] = None
    message_id: Optional[int] = None
    error: Optional["BaseMessageError"] = None


class SetChatPhotoResponseModel(BaseResponse):
    message_id: Optional[int] = None
    chat: Optional["MessagesChat"] = None


CreateChatResponse.update_forward_refs()
DeleteChatPhotoResponse.update_forward_refs()
DeleteConversationResponse.update_forward_refs()
DeleteResponse.update_forward_refs()
EditResponse.update_forward_refs()
GetByConversationMessageIdResponse.update_forward_refs()
GetByIdExtendedResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetChatPreviewResponse.update_forward_refs()
GetChatChatIdsFieldsResponse.update_forward_refs()
GetChatChatIdsResponse.update_forward_refs()
GetChatFieldsResponse.update_forward_refs()
GetChatResponse.update_forward_refs()
GetConversationMembersResponse.update_forward_refs()
GetConversationsByIdExtendedResponse.update_forward_refs()
GetConversationsByIdResponse.update_forward_refs()
GetConversationsResponse.update_forward_refs()
GetHistoryAttachmentsResponse.update_forward_refs()
GetHistoryResponse.update_forward_refs()
GetInviteLinkResponse.update_forward_refs()
GetLastActivityResponse.update_forward_refs()
GetLongPollHistoryResponse.update_forward_refs()
GetLongPollServerResponse.update_forward_refs()
IsMessagesFromGroupAllowedResponse.update_forward_refs()
JoinChatByInviteLinkResponse.update_forward_refs()
MarkAsImportantResponse.update_forward_refs()
PinResponse.update_forward_refs()
SearchConversationsResponse.update_forward_refs()
SearchResponse.update_forward_refs()
SendResponse.update_forward_refs()
SendUserIdsResponse.update_forward_refs()
SetChatPhotoResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.responses import gifts
from .base_category import BaseCategory


class GiftsCategory(BaseCategory):
    async def get(
        self,
        user_id: Optional[int] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        **kwargs
    ) -> gifts.GetResponseModel:
        """Returns a list of user gifts.
        :param user_id: User ID.
        :param count: Number of gifts to return.
        :param offset: Offset needed to return a specific subset of results.
        """

        params = self.get_set_params(locals())
        return gifts.GetResponse(**await self.api.request("gifts.get", params))



from typing import Optional, List

from vkbottle_types.objects import PrettyCardsPrettyCard
from .base_response import BaseResponse


class CreateResponse(BaseResponse):
    response: Optional["CreateResponseModel"] = None


class DeleteResponse(BaseResponse):
    response: Optional["DeleteResponseModel"] = None


class EditResponse(BaseResponse):
    response: Optional["EditResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetUploadURLResponse(BaseResponse):
    response: Optional["GetUploadURLResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class CreateResponseModel(BaseResponse):
    owner_id: Optional[int] = None
    card_id: Optional[str] = None


class DeleteResponseModel(BaseResponse):
    owner_id: Optional[int] = None
    card_id: Optional[str] = None
    error: Optional[str] = None


class EditResponseModel(BaseResponse):
    owner_id: Optional[int] = None
    card_id: Optional[str] = None


GetByIdResponseModel = List[PrettyCardsPrettyCard]


GetUploadURLResponseModel = str


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["PrettyCardsPrettyCard"]] = None


CreateResponse.update_forward_refs()
DeleteResponse.update_forward_refs()
EditResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetUploadURLResponse.update_forward_refs()
GetResponse.update_forward_refs()



import typing
from typing import Optional, List

from vkbottle_types.responses import wall, base
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import base as objects_base


class WallCategory(BaseCategory):
    async def close_comments(
        self, owner_id: int, post_id: int, **kwargs
    ) -> base.BoolResponseModel:
        """wall.closeComments method
        :param owner_id:
        :param post_id:
        """

        params = self.get_set_params(locals())
        return base.BoolResponse(**await self.api.request("wall.closeComments", params))

    async def create_comment(
        self,
        post_id: int,
        owner_id: Optional[int] = None,
        from_group: Optional[int] = None,
        message: Optional[str] = None,
        reply_to_comment: Optional[int] = None,
        attachments: Optional[List[str]] = None,
        sticker_id: Optional[int] = None,
        guid: Optional[str] = None,
        **kwargs
    ) -> wall.CreateCommentResponseModel:
        """Adds a comment to a post on a user wall or community wall.
        :param post_id: Post ID.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param from_group: Group ID.
        :param message: (Required if 'attachments' is not set., **kwargs) Text of the comment.
        :param reply_to_comment: ID of comment to reply.
        :param attachments: (Required if 'message' is not set., **kwargs) List of media objects attached to the comment, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media ojbect: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, '<owner_id>' — ID of the media owner. '<media_id>' — Media ID. For example: "photo100172_166443618,photo66748_265827614"
        :param sticker_id: Sticker ID.
        :param guid: Unique identifier to avoid repeated comments.
        """

        params = self.get_set_params(locals())
        return wall.CreateCommentResponse(
            **await self.api.request("wall.createComment", params)
        )

    async def delete(
        self, owner_id: Optional[int] = None, post_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Deletes a post from a user wall or community wall.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param post_id: ID of the post to be deleted.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.delete", params))

    async def delete_comment(
        self, comment_id: int, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Deletes a comment on a post on a user wall or community wall.
        :param comment_id: Comment ID.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.deleteComment", params))

    async def edit(
        self,
        post_id: int,
        owner_id: Optional[int] = None,
        friends_only: Optional[bool] = None,
        message: Optional[str] = None,
        attachments: Optional[List[str]] = None,
        services: Optional[str] = None,
        signed: Optional[bool] = None,
        publish_date: Optional[int] = None,
        lat: Optional[float] = None,
        long: Optional[float] = None,
        place_id: Optional[int] = None,
        mark_as_ads: Optional[bool] = None,
        close_comments: Optional[bool] = None,
        poster_bkg_id: Optional[int] = None,
        poster_bkg_owner_id: Optional[int] = None,
        poster_bkg_access_hash: Optional[str] = None,
        copyright: Optional[str] = None,
        **kwargs
    ) -> wall.EditResponseModel:
        """Edits a post on a user wall or community wall.
        :param post_id:
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param friends_only:
        :param message: (Required if 'attachments' is not set., **kwargs) Text of the post.
        :param attachments: (Required if 'message' is not set., **kwargs) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, '<owner_id>' — ID of the media application owner. '<media_id>' — Media application ID. Example: "photo100172_166443618,photo66748_265827614", May contain a link to an external page to include in the post. Example: "photo66748_265827614,http://habrahabr.ru", "NOTE: If more than one link is being attached, an error is thrown."
        :param services:
        :param signed:
        :param publish_date:
        :param lat:
        :param long:
        :param place_id:
        :param mark_as_ads:
        :param close_comments:
        :param poster_bkg_id:
        :param poster_bkg_owner_id:
        :param poster_bkg_access_hash:
        :param copyright:
        """

        params = self.get_set_params(locals())
        return wall.EditResponse(**await self.api.request("wall.edit", params))

    async def edit_ads_stealth(
        self,
        post_id: int,
        owner_id: Optional[int] = None,
        message: Optional[str] = None,
        attachments: Optional[List[str]] = None,
        signed: Optional[bool] = None,
        lat: Optional[float] = None,
        long: Optional[float] = None,
        place_id: Optional[int] = None,
        link_button: Optional[str] = None,
        link_title: Optional[str] = None,
        link_image: Optional[str] = None,
        link_video: Optional[str] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Allows to edit hidden post.
        :param post_id: Post ID. Used for publishing of scheduled and suggested posts.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param message: (Required if 'attachments' is not set., **kwargs) Text of the post.
        :param attachments: (Required if 'message' is not set., **kwargs) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'page' — wiki-page, 'note' — note, 'poll' — poll, 'album' — photo album, '<owner_id>' — ID of the media application owner. '<media_id>' — Media application ID. Example: "photo100172_166443618,photo66748_265827614", May contain a link to an external page to include in the post. Example: "photo66748_265827614,http://habrahabr.ru", "NOTE: If more than one link is being attached, an error will be thrown."
        :param signed: Only for posts in communities with 'from_group' set to '1': '1' — post will be signed with the name of the posting user, '0' — post will not be signed (default)
        :param lat: Geographical latitude of a check-in, in degrees (from -90 to 90).
        :param long: Geographical longitude of a check-in, in degrees (from -180 to 180).
        :param place_id: ID of the location where the user was tagged.
        :param link_button: Link button ID
        :param link_title: Link title
        :param link_image: Link image url
        :param link_video: Link video ID in format "<owner_id>_<media_id>"
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.editAdsStealth", params))

    async def edit_comment(
        self,
        comment_id: int,
        owner_id: Optional[int] = None,
        message: Optional[str] = None,
        attachments: Optional[List[str]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Edits a comment on a user wall or community wall.
        :param comment_id: Comment ID.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param message: New comment text.
        :param attachments: List of objects attached to the comment, in the following format: , "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, '<owner_id>' — ID of the media attachment owner. '<media_id>' — Media attachment ID. For example: "photo100172_166443618,photo66748_265827614"
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.editComment", params))

    async def get(
        self,
        owner_id: Optional[int] = None,
        domain: Optional[str] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        filter: Optional[str] = None,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> wall.GetExtendedResponseModel:
        """Returns a list of posts on a user wall or community wall.
        :param owner_id: ID of the user or community that owns the wall. By default, current user ID. Use a negative value to designate a community ID.
        :param domain: User or community short address.
        :param offset: Offset needed to return a specific subset of posts.
        :param count: Number of posts to return (maximum 100).
        :param filter: Filter to apply: 'owner' — posts by the wall owner, 'others' — posts by someone else, 'all' — posts by the wall owner and others (default), 'postponed' — timed posts (only available for calls with an 'access_token'), 'suggests' — suggested posts on a community wall
        :param extended: '1' — to return 'wall', 'profiles', and 'groups' fields, '0' — to return no additional fields (default)
        :param fields:
        """

        params = self.get_set_params(locals())
        return wall.GetExtendedResponse(**await self.api.request("wall.get", params))

    async def get_by_id(
        self,
        posts: List[str],
        extended: Optional[bool] = None,
        copy_history_depth: Optional[int] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> wall.GetByIdExtendedResponseModel:
        """Returns a list of posts from user or community walls by their IDs.
        :param posts: User or community IDs and post IDs, separated by underscores. Use a negative value to designate a community ID. Example: "93388_21539,93388_20904,2943_4276,-1_1"
        :param extended: '1' — to return user and community objects needed to display posts, '0' — no additional fields are returned (default)
        :param copy_history_depth: Sets the number of parent elements to include in the array 'copy_history' that is returned if the post is a repost from another wall.
        :param fields:
        """

        params = self.get_set_params(locals())
        return wall.GetByIdExtendedResponse(
            **await self.api.request("wall.getById", params)
        )

    async def get_comment(
        self,
        comment_id: int,
        owner_id: Optional[int] = None,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> wall.GetCommentExtendedResponseModel:
        """Returns a comment on a post on a user wall or community wall.
        :param comment_id: Comment ID.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param extended:
        :param fields:
        """

        params = self.get_set_params(locals())
        return wall.GetCommentExtendedResponse(
            **await self.api.request("wall.getComment", params)
        )

    async def get_comments(
        self,
        owner_id: Optional[int] = None,
        post_id: Optional[int] = None,
        need_likes: Optional[bool] = None,
        start_comment_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        sort: Optional[str] = None,
        preview_length: Optional[int] = None,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        comment_id: Optional[int] = None,
        thread_items_count: Optional[int] = None,
        **kwargs
    ) -> wall.GetCommentsExtendedResponseModel:
        """Returns a list of comments on a post on a user wall or community wall.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param post_id: Post ID.
        :param need_likes: '1' — to return the 'likes' field, '0' — not to return the 'likes' field (default)
        :param start_comment_id:
        :param offset: Offset needed to return a specific subset of comments.
        :param count: Number of comments to return (maximum 100).
        :param sort: Sort order: 'asc' — chronological, 'desc' — reverse chronological
        :param preview_length: Number of characters at which to truncate comments when previewed. By default, '90'. Specify '0' if you do not want to truncate comments.
        :param extended:
        :param fields:
        :param comment_id: Comment ID.
        :param thread_items_count: Count items in threads.
        """

        params = self.get_set_params(locals())
        return wall.GetCommentsExtendedResponse(
            **await self.api.request("wall.getComments", params)
        )

    async def get_reposts(
        self,
        owner_id: Optional[int] = None,
        post_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> wall.GetRepostsResponseModel:
        """Returns information about reposts of a post on user wall or community wall.
        :param owner_id: User ID or community ID. By default, current user ID. Use a negative value to designate a community ID.
        :param post_id: Post ID.
        :param offset: Offset needed to return a specific subset of reposts.
        :param count: Number of reposts to return.
        """

        params = self.get_set_params(locals())
        return wall.GetRepostsResponse(
            **await self.api.request("wall.getReposts", params)
        )

    async def open_comments(
        self, owner_id: int, post_id: int, **kwargs
    ) -> base.BoolResponseModel:
        """wall.openComments method
        :param owner_id:
        :param post_id:
        """

        params = self.get_set_params(locals())
        return base.BoolResponse(**await self.api.request("wall.openComments", params))

    async def pin(
        self, post_id: int, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Pins the post on wall.
        :param post_id: Post ID.
        :param owner_id: ID of the user or community that owns the wall. By default, current user ID. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.pin", params))

    async def post(
        self,
        owner_id: Optional[int] = None,
        friends_only: Optional[bool] = None,
        from_group: Optional[bool] = None,
        message: Optional[str] = None,
        attachments: Optional[List[str]] = None,
        services: Optional[str] = None,
        signed: Optional[bool] = None,
        publish_date: Optional[int] = None,
        lat: Optional[float] = None,
        long: Optional[float] = None,
        place_id: Optional[int] = None,
        post_id: Optional[int] = None,
        guid: Optional[str] = None,
        mark_as_ads: Optional[bool] = None,
        close_comments: Optional[bool] = None,
        mute_notifications: Optional[bool] = None,
        copyright: Optional[str] = None,
        **kwargs
    ) -> wall.PostResponseModel:
        """Adds a new post on a user wall or community wall. Can also be used to publish suggested or scheduled posts.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param friends_only: '1' — post will be available to friends only, '0' — post will be available to all users (default)
        :param from_group: For a community: '1' — post will be published by the community, '0' — post will be published by the user (default)
        :param message: (Required if 'attachments' is not set., **kwargs) Text of the post.
        :param attachments: (Required if 'message' is not set., **kwargs) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'page' — wiki-page, 'note' — note, 'poll' — poll, 'album' — photo album, '<owner_id>' — ID of the media application owner. '<media_id>' — Media application ID. Example: "photo100172_166443618,photo66748_265827614", May contain a link to an external page to include in the post. Example: "photo66748_265827614,http://habrahabr.ru", "NOTE: If more than one link is being attached, an error will be thrown."
        :param services: List of services or websites the update will be exported to, if the user has so requested. Sample values: 'twitter', 'facebook'.
        :param signed: Only for posts in communities with 'from_group' set to '1': '1' — post will be signed with the name of the posting user, '0' — post will not be signed (default)
        :param publish_date: Publication date (in Unix time). If used, posting will be delayed until the set time.
        :param lat: Geographical latitude of a check-in, in degrees (from -90 to 90).
        :param long: Geographical longitude of a check-in, in degrees (from -180 to 180).
        :param place_id: ID of the location where the user was tagged.
        :param post_id: Post ID. Used for publishing of scheduled and suggested posts.
        :param guid:
        :param mark_as_ads:
        :param close_comments:
        :param mute_notifications:
        :param copyright:
        """

        params = self.get_set_params(locals())
        return wall.PostResponse(**await self.api.request("wall.post", params))

    async def post_ads_stealth(
        self,
        owner_id: int,
        message: Optional[str] = None,
        attachments: Optional[List[str]] = None,
        signed: Optional[bool] = None,
        lat: Optional[float] = None,
        long: Optional[float] = None,
        place_id: Optional[int] = None,
        guid: Optional[str] = None,
        link_button: Optional[str] = None,
        link_title: Optional[str] = None,
        link_image: Optional[str] = None,
        link_video: Optional[str] = None,
        **kwargs
    ) -> wall.PostAdsStealthResponseModel:
        """Allows to create hidden post which will not be shown on the community's wall and can be used for creating an ad with type "Community post".
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param message: (Required if 'attachments' is not set., **kwargs) Text of the post.
        :param attachments: (Required if 'message' is not set., **kwargs) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'page' — wiki-page, 'note' — note, 'poll' — poll, 'album' — photo album, '<owner_id>' — ID of the media application owner. '<media_id>' — Media application ID. Example: "photo100172_166443618,photo66748_265827614", May contain a link to an external page to include in the post. Example: "photo66748_265827614,http://habrahabr.ru", "NOTE: If more than one link is being attached, an error will be thrown."
        :param signed: Only for posts in communities with 'from_group' set to '1': '1' — post will be signed with the name of the posting user, '0' — post will not be signed (default)
        :param lat: Geographical latitude of a check-in, in degrees (from -90 to 90).
        :param long: Geographical longitude of a check-in, in degrees (from -180 to 180).
        :param place_id: ID of the location where the user was tagged.
        :param guid: Unique identifier to avoid duplication the same post.
        :param link_button: Link button ID
        :param link_title: Link title
        :param link_image: Link image url
        :param link_video: Link video ID in format "<owner_id>_<media_id>"
        """

        params = self.get_set_params(locals())
        return wall.PostAdsStealthResponse(
            **await self.api.request("wall.postAdsStealth", params)
        )

    async def report_comment(
        self, owner_id: int, comment_id: int, reason: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Reports (submits a complaint about, **kwargs) a comment on a post on a user wall or community wall.
        :param owner_id: ID of the user or community that owns the wall.
        :param comment_id: Comment ID.
        :param reason: Reason for the complaint: '0' – spam, '1' – child pornography, '2' – extremism, '3' – violence, '4' – drug propaganda, '5' – adult material, '6' – insult, abuse
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.reportComment", params))

    async def report_post(
        self, owner_id: int, post_id: int, reason: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Reports (submits a complaint about, **kwargs) a post on a user wall or community wall.
        :param owner_id: ID of the user or community that owns the wall.
        :param post_id: Post ID.
        :param reason: Reason for the complaint: '0' – spam, '1' – child pornography, '2' – extremism, '3' – violence, '4' – drug propaganda, '5' – adult material, '6' – insult, abuse
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.reportPost", params))

    async def repost(
        self,
        object: str,
        message: Optional[str] = None,
        group_id: Optional[int] = None,
        mark_as_ads: Optional[bool] = None,
        mute_notifications: Optional[bool] = None,
        **kwargs
    ) -> wall.RepostResponseModel:
        """Reposts (copies, **kwargs) an object to a user wall or community wall.
        :param object: ID of the object to be reposted on the wall. Example: "wall66748_3675"
        :param message: Comment to be added along with the reposted object.
        :param group_id: Target community ID when reposting to a community.
        :param mark_as_ads:
        :param mute_notifications:
        """

        params = self.get_set_params(locals())
        return wall.RepostResponse(**await self.api.request("wall.repost", params))

    async def restore(
        self, owner_id: Optional[int] = None, post_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Restores a post deleted from a user wall or community wall.
        :param owner_id: User ID or community ID from whose wall the post was deleted. Use a negative value to designate a community ID.
        :param post_id: ID of the post to be restored.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.restore", params))

    async def restore_comment(
        self, comment_id: int, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Restores a comment deleted from a user wall or community wall.
        :param comment_id: Comment ID.
        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.restoreComment", params))

    async def search(
        self,
        owner_id: Optional[int] = None,
        domain: Optional[str] = None,
        query: Optional[str] = None,
        owners_only: Optional[bool] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> wall.SearchExtendedResponseModel:
        """Allows to search posts on user or community walls.
        :param owner_id: user or community id. "Remember that for a community 'owner_id' must be negative."
        :param domain: user or community screen name.
        :param query: search query string.
        :param owners_only: '1' – returns only page owner's posts.
        :param count: count of posts to return.
        :param offset: Offset needed to return a specific subset of posts.
        :param extended: show extended post info.
        :param fields:
        """

        params = self.get_set_params(locals())
        return wall.SearchExtendedResponse(
            **await self.api.request("wall.search", params)
        )

    async def unpin(
        self, post_id: int, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Unpins the post on wall.
        :param post_id: Post ID.
        :param owner_id: ID of the user or community that owns the wall. By default, current user ID. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("wall.unpin", params))



from typing import Optional, List

from vkbottle_types.responses import search
from .base_category import BaseCategory


class SearchCategory(BaseCategory):
    async def get_hints(
        self,
        q: Optional[str] = None,
        offset: Optional[int] = None,
        limit: Optional[int] = None,
        filters: Optional[List[str]] = None,
        fields: Optional[List[str]] = None,
        search_global: Optional[bool] = None,
        **kwargs
    ) -> search.GetHintsResponseModel:
        """Allows the programmer to do a quick search for any substring.
        :param q: Search query string.
        :param offset: Offset for querying specific result subset
        :param limit: Maximum number of results to return.
        :param filters:
        :param fields:
        :param search_global:
        """

        params = self.get_set_params(locals())
        return search.GetHintsResponse(
            **await self.api.request("search.getHints", params)
        )



from typing import Optional, List

from vkbottle_types.objects import (
    DocsDocTypes,
    MessagesAudioMessage,
    MessagesGraffiti,
    DocsDocAttachmentType,
    DocsDoc,
    BaseUploadServer,
)
from .base_response import BaseResponse


class AddResponse(BaseResponse):
    response: Optional["AddResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetTypesResponse(BaseResponse):
    response: Optional["GetTypesResponseModel"] = None


class GetUploadServer(BaseResponse):
    response: Optional["GetUploadServerModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class SaveResponse(BaseResponse):
    response: Optional["SaveResponseModel"] = None


class SearchResponse(BaseResponse):
    response: Optional["SearchResponseModel"] = None


class AddResponseModel(BaseResponse):
    id: Optional[int] = None


GetByIdResponseModel = List[DocsDoc]


class GetTypesResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DocsDocTypes"]] = None


GetUploadServerModel = Optional[BaseUploadServer]


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DocsDoc"]] = None


class SaveResponseModel(BaseResponse):
    type: Optional["DocsDocAttachmentType"] = None
    audio_message: Optional["MessagesAudioMessage"] = None
    doc: Optional["DocsDoc"] = None
    graffiti: Optional["MessagesGraffiti"] = None


class SearchResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DocsDoc"]] = None


AddResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetTypesResponse.update_forward_refs()
GetUploadServer.update_forward_refs()
GetResponse.update_forward_refs()
SaveResponse.update_forward_refs()
SearchResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    UsersUserXtrCounters,
    UsersUsersArray,
    UsersUserFull,
    GroupsGroupsArray,
    UsersSubscriptionsItem,
)
from .base_response import BaseResponse


class GetFollowersFieldsResponse(BaseResponse):
    response: Optional["GetFollowersFieldsResponseModel"] = None


class GetFollowersResponse(BaseResponse):
    response: Optional["GetFollowersResponseModel"] = None


class GetSubscriptionsExtendedResponse(BaseResponse):
    response: Optional["GetSubscriptionsExtendedResponseModel"] = None


class GetSubscriptionsResponse(BaseResponse):
    response: Optional["GetSubscriptionsResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class SearchResponse(BaseResponse):
    response: Optional["SearchResponseModel"] = None


class GetFollowersFieldsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["UsersUserFull"]] = None


class GetFollowersResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List[int]] = None


class GetSubscriptionsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["UsersSubscriptionsItem"]] = None


class GetSubscriptionsResponseModel(BaseResponse):
    users: Optional["UsersUsersArray"] = None
    groups: Optional["GroupsGroupsArray"] = None


GetResponseModel = List[UsersUserXtrCounters]


class SearchResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["UsersUserFull"]] = None


GetFollowersFieldsResponse.update_forward_refs()
GetFollowersResponse.update_forward_refs()
GetSubscriptionsExtendedResponse.update_forward_refs()
GetSubscriptionsResponse.update_forward_refs()
GetResponse.update_forward_refs()
SearchResponse.update_forward_refs()
